#
# spec file for package rclone
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


Name:           rclone
Version:        1.68.2
Release:        2.1
Summary:        Rsync for cloud storage
License:        MIT
Group:          Productivity/Networking/Web/Utilities
URL:            https://rclone.org/
Source:         %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
BuildRequires:  fdupes
BuildRequires:  go >= 1.20
BuildRequires:  golang-packaging
%if 0%{?sle_version} >= 150500 && 0%{?sle_version} < 160000 && 0%{?is_opensuse}
BuildRequires:  gcc11
%else
BuildRequires:  gcc
%endif

%description
rsync for cloud storage. rclone is a command line program to sync files and
directories to and from a wide variety of cloud storage providers, providing
various additional features.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          Productivity/Networking/Web/Utilities
Requires:       %{name} = %{version}
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          Productivity/Networking/Web/Utilities
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%prep
%setup -q
%setup -q -D -T -a 1
%autopatch -p1

%build
%if 0%{?sle_version} >= 150500 && 0%{?sle_version} < 160000 && 0%{?is_opensuse}
export CC="gcc-11"
%endif
# pie not supported on ppc64
go build -o %{name} \
%ifnarch ppc64
  -buildmode=pie \
%endif
  -mod=vendor \
  --ldflags '-X github.com/rclone/rclone/fs.Version=v%{version}'

./%{name} version

./%{name} genautocomplete bash completion.bash
./%{name} genautocomplete zsh  completion.zsh

%install
install -m0755 -D %{name} %{buildroot}%{_bindir}/%{name}
install -m0644 -D %{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1

install -m0644 -D completion.bash %{buildroot}%{_datadir}/bash/%{name}
install -m0644 -D completion.zsh  %{buildroot}%{_datadir}/zsh/_%{name}

%fdupes %{buildroot}

%files
%doc MANUAL.md README.md RELEASE.md
%license COPYING
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%files bash-completion
%{_datadir}/bash/

%files zsh-completion
%{_datadir}/zsh/

%changelog
* Fri Nov 15 2024 mrueckert@suse.de
- Update to version 1.68.2:
  * Version v1.68.2
  * s3: fix multitenant multipart uploads with CEPH
  * local: fix permission and ownership on symlinks with --links and --metadata
    CVE-2024-52522 boo#1233422
  * bisync: fix output capture restoring the wrong output for logrus
  * build: fix comments after golangci-lint upgrade
  * build(deps): bump github.com/golang-jwt/jwt/v4 from 4.5.0 to 4.5.1
  * pikpak: fix fatal crash on startup with token that can't be refreshed
  * serve s3: fix excess locking which was making serve s3 single threaded
  * onedrive: fix Retry-After handling to look at 503 errors also
  * s3: Storj provider: fix server-side copy of files bigger than 5GB
  * docs: mention that inline comments are not supported in a filter-file
  * docs: fix forward refs in step 9 of using your own client id
  * docs: fix Scaleway Glacier website URL
  * dlna: fix loggingResponseWriter disregarding log level
  * s3: fix crash when using --s3-download-url after migration to SDKv2
  * docs: update overview to show pcloud can set modtime
  * Add RcloneView as a sponsor
  * accounting: fix wrong message on SIGUSR2 to enable/disable bwlimit
  * pikpak: fix cid/gcid calculations for fs.OverrideRemote
  * local: fix --copy-links on macOS when cloning
  * Start v1.68.2-DEV development
- drop CVE-2024-51744.patch
* Thu Nov  7 2024 Paolo Stivanin <info@paolostivanin.com>
- Add CVE-2024-51744.patch: this updates jwt v4.5.1 which contains
  the fix for CVE-2024-51744 (bsc#1232964).
* Tue Sep 24 2024 mrueckert@suse.de
- Update to version 1.68.1:
  * Version v1.68.1
  * docs: document that fusermount3 may be needed when mounting/unmounting
  * pikpak: fix login issue where token retrieval fails
  * s3: fix rclone ignoring static credentials when env_auth=true
  * fs: fix setting stringArray config values from environment variables
  * rc: fix default value of --metrics-addr
  * fs: fix --dump filters not always appearing
  * docs: correct notes on docker manual build
  * build: fix docker release build - fixes #8062
  * docs: add section for improving performance for s3
  * onedrive: fix spurious "Couldn't decode error response: EOF" DEBUG
  * serve docker: add missing vfs-read-chunk-streams option in docker volume driver
  * Start v1.68.1-DEV development
* Sun Sep  8 2024 mrueckert@suse.de
- Update to version 1.68.0:
  * Version v1.68.0
  * gofile: fix failed downloads on newly uploaded objects
  * gofile: fix Move a file
  * test_all: mark linkbox fs/sync test TestSyncOverlapWithFilter as ignore
  * jottacloud: fix setting of metadata on server side move - fixes #7900
  * docs: group the different options affecting lsjson output
  * fichier: fix server side move - fixes #7856
  * fichier: Fix detection of Flood Detected error
  * rc: add vfs/queue-set-expiry to adjust expiry of items in the VFS queue
  * rc: add vfs/queue to show the status of the upload queue
  * vfs: keep a record of the file size in the writeback queue
  * build: fix gocritic change missed in merge
  * Add Oleg Kunitsyn to contributors
  * Add fsantagostinobietti to contributors
  * Add Mathieu Moreau to contributors
  * lib/sd-activation: wrap coreos/go-systemd
  * sftp: support listening on passed FDs
  * http: fix addr CLI arg help text
  * http: support listening on passed FDs
  * build: fix build after update
  * build: update logging statements to make json log work - fixes #6038
  * build: update custom linting rule for log to suggest new non-format functions
  * fs: add non-format variants of log functions to avoid non-constant format string warnings
  * fs: add log Printf, Fatalf and Panicf
  * fs: refactor base log method name for improved consistency
  * fs: refactor log statements to use common helper
  * build: enable custom linting rules with ruleguard via gocritic
  * rcserver: implement prometheus metrics on a dedicated port - fixes #7940
  * swift: add total/free space info in about command.
  * docs: filtering: added Byte unit for min/max-size parameters.
  * config encryption: set, remove and check to manage config file encryption #7859
  * config: use --password-command to set config file password if supplied
  * config: factor --password-command code into its own function #7859
  * Add yuval-cloudinary to contributors
  * Add nipil to contributors
  * documentation: add cheatsheet for configuration encryption
  * docs: more secure two-step signature and hash validation
  * serve nfs: unify the nfs library logging with rclone's logging better
  * serve nfs: fix incorrect user id and group id exported to NFS #7973
  * zoho: fix inefficiencies uploading with new API to avoid throttling
  * Add crystalstall to contributors
  * docs: fix some function names in comments
  * lib/file: use builtin MkdirAll with go1.22 instead of our own custom version for windows
  * docs: document that paths using volume guids are supported
  * s3: fix accounting for mulpart transfers after migration to SDKv2 #4989
  * yandex: implement custom user agent to help with upload speeds
  * operations: copy: generate stable partial suffix
  * docs: add missing sftp providers to README and main docs page - fixes #8038
  * nfsmount: fix stale handle problem after converting options to new style
  * docs: mark flags.md as auto generated so contributors don't edit it
  * Add Pawel Palucha to contributors
  * Add John Oxley to contributors
  * Add Georg Welzel to contributors
  * Add Péter Bozsó to contributors
  * Add Sam Harrison to contributors
  * s3: allow restoring from intelligent-tiering storage class
  * bisync: don't convert modtime precision in listings - fixes #8025
  * build: rename Unknwon/goconfig to unknwon/goconfig
  * backend: pcloud: Implement OpenWriterAt feature
  * backend: pcloud: implement SetModTime - Fixes #7896
  * filescom: don't make an extra fetch call on each item in a list response
  * local: fix incorrect conversion between integer types
  * local: fix incorrect conversion between integer types
  * docs: make tardigrade page auto redirect to storj page
  * docs: update backend config samples
  * config: fix size computation for allocation may overflow
  * lib: fix incorrect conversion between integer types
  * serve docker: fix incorrect conversion between integer types
  * local: fix incorrect conversion between integer types
  * s3: fix incorrect conversion between integer types
  * s3: fix potentially unsafe quoting issue
  * dropbox: fix potentially unsafe quoting issue
  * refactor: replace min/max helpers with built-in min/max
  * go.mod: update storj.io/uplink to latest release
  * docs: update ssh tunnel example
  * docs: update rclone authorize section
  * docs: fix command highlight
  * docs: fix alignment of some of the icons in the storage system dropdown
  * docs: mark filescom as supporting link sharing
  * build: enable gocritic linter
  * build: ignore remaining gocritic lint issues
  * build: fix gocritic lint issue unlambda
  * build: fix gocritic lint issue dupbranchbody
  * build: fix gocritic lint issue sloppylen
  * build: fix gocritic lint issue wrapperfunc
  * build: fix gocritic lint issue elseif
  * build: fix gocritic lint issue underef
  * build: fix gocritic lint issue valswap
  * build: fix gocritic lint issue assignop
  * build: fix gocritic lint issue unslice
  * dlna: document external subtitle feature
  * dlna: set more correct mime type
  * dlna: don't swallow video.{idx,sub}
  * dlna: add cds_test.go
  * dlna: also look at "Subs" subdirectory
  * chore: add childish-sambino as filescom maintainer
  * Make filtering rules for help and listremotes more lenient
  * help: cleanup template syntax (consistent whitespace)
  * help: avoid empty additional help topics header
  * help: make help command output less distracting
  * docs: consistent newline of first line in command output
  * filescom: add Files.com backend
  * fstests: attempt to fix flaky serve s3 test
  * docs: move the link to global flags page to the main options header
  * docs: make command group options subsections of main options
  * docs: stop shouting the SEE ALSO header
  * docs: fix the rclone root command header levels
  * docs: make the see also section header consistent and listed in toc of command pages
  * local: --local-no-clone flag to disable cloning for server-side copies
  * local: support setting custom --metadata during server-side Copy
  * local: add server-side copy with xattrs on macOS (part-fix #1710)
  * docs: add automatic alias redirects for command pages
  * cmd/rc: add --unix-socket option
  * webdav: add --webdav-unix-socket-path to connect to a unix socket
  * serve nfs: implement on disk cache for file handles
  * serve nfs: factor caching to its own file
  * serve nfs: update github.com/willscott/go-nfs to latest
  * serve nfs: store billy FS in the Handler
  * serve nfs: mask unimplemented error from chmod
  * serve nfs: add tracing to filesystem calls
  * serve nfs: rename types and methods which should be internal
  * nfsmount: require --vfs-cache-mode writes or above in tests
  * nfsmount: allow tests to run on any unix where sudo mount/umount works
  * nfsmount: make the --sudo flag work for umount as well as mount
  * nfsmount: add tcp option to NFS mount options to fix mounting under Linux
  * build: install NFS client libraries to allow nfsmount tests to run
  * vfstest: fix crash if open failed
  * Implement Gofile backend - fixes #4632
  * lib/encoder: add Exclamation mark encoding
  * chunkedreader: add --vfs-read-chunk-streams to parallel read chunks
  * accounting: fix race detected by the race detector
  * pool: Add ability to wait for a write to RW
  * pool: Make RW thread safe so can read and write at the same time
  * multipart: make pool buffer size public
  * Add Fornax to contributors
  * build: use go1.23 for the linter
  * build: fix govet lint errors with golangci-lint v1.60.1
  * build: bisync: fix govet lint errors with golangci-lint v1.60.1
  * build: fix staticcheck lint errors with golangci-lint v1.60.1
  * build: fix gosimple lint errors with golangci-lint v1.60.1
  * drive: fix copying Google Docs to a backend which only supports SHA1
  * drive: update docs on creating admin service accounts
  * Add pixeldrain backend
  * docs: add comment how to reduce rclone binary size (#8000)
  * Make listremotes long output backwards compatible - fixes #7995
  * test_backend_sizes.py calculates space in the binary each backend uses #7998
  * listremotes: added options for filtering, ordering and json output
  * config: make getting config values more consistent
  * config: make listing of remotes more consistent
  * config: avoid remote with empty name from environment
  * help: global flags help command extended filtering
  * help: global flags help command now takes glob filter
  * filter: add options for glob to regexp without anchors and special path rules
  * docs: remove old genautocomplete command docs and add as alias from the newer completion command
  * docs: replace references to genautocomplete with the new name completion
  * serve s3: update to AWS SDKv2 by updating github.com/rclone/gofakes3
  * s3: fix SSE-C after SDKv2 change
  * pikpak: update to using AWS SDK v2 #4989
  * s3: fix Cloudflare R2 integration tests after SDKv2 update #4989
  * s3: add --s3-sdk-log-mode to control SDK debugging
  * s3: fix GCS provider after SDKv2 update #4989
  * s3: update to using AWS SDK v2 - fixes #4989
  * fstest: implement method to skip ChunkedCopy tests
  * build: disable wasm/js build due to go bug
  * Add @dmcardle as gitannex maintainer
  * docs: s3: add section on using too much memory #7974
  * docs: link the workaround for big directory syncs in the FAQ #7974
  * Add David Seifert to contributors
  * Add Will Miles to contributors
  * Add Ernie Hershey to contributors
  * docs: rc: fix correct _path to _root in on the fly backend docs
  * fs/http: reload client certificates on expiry
  * docs: clarify hasher operation
  * docs: fix typo in batcher docs for dropbox and googlephotos
  * b2: update versions documentation - fixes #7878
  * s3: document need to set force_path_style for buckets with invalid DNS names
  * ncdu: document that excludes are not shown - fixes #6087
  * sftp: clarify the docs for key_pem - fixes #7921
  * serve ftp: fix failed startup due to config changes
  * docs: add Route4Me as a sponsor
  * pikpak: correct file transfer progress for uploads by hash
  * fs: fix --use-json-log and -vv after config reorganization
  * Add Tobias Markus to contributors
  * ulozto: fix upload of > 2GB files on 32 bit platforms - fixes #7960
  * lib/mmap: fix lint error on deprecated reflect.SliceHeader
  * lib/http: fix tests after go1.23 update
  * rc: fix tests after go1.23 upgrade
  * build: use go1.22 for the linter to fix excess memory usage
  * build: update all dependencies
  * build: update to go1.23rc1 and make go1.21 the minimum required version
  * Add AThePeanut4 to contributors
  * systemd: prevent unmount rc command from sending a STOPPING=1 sd-notify message
  * azureblob: allow anonymous access for public resources
  * Add Ke Wang to contributors
  * Add itsHenry to contributors
  * Add Tomasz Melcer to contributors
  * Add Paul Collins to contributors
  * Add Russ Bubley to contributors
  * serve s3: implement `--auth-proxy`
  * fs: Allow semicolons as well as spaces in --bwlimit timetable parsing - fixes #7595
  * pikpak: optimize upload by pre-fetching gcid from API
  * rc: add option blocks parameter to options/get and options/info
  * chore(deps): update github.com/rclone/gofakes3
  * fstest: fix compile after merge
  * local: fix encoding of root path fix #7824 Statements like rclone copy <somewhere> . will spontaneously miss if . expands to a path with a Full Width replacement character. This is due to the incorrect order in which relative paths and decoding were handled in the original implementation.
  * vfs: fix cache encoding with special characters - #7760
  * docs: correct description of encoding None and add Raw.
  * lib/encoder: add EncodeRaw
  * pikpak: non-buffered hash calculation for local source files
  * b2: Include custom upload headers in large file info - fixes #7744
  * chore(deps): update github.com/rclone/gofakes3
  * fs/test: fix erratic test
  * fs: make sure we load the options defaults to start with
  * fs: fix the defaults overriding the actual config
  * rc: add options/info call to enumerate options
  * fs: convert main options to new config system
  * accounting: fix creating of global stats ignoring the config
  * filter: convert options to new style
  * filter: rename Opt to Options for consistency
  * rc: convert options to new style
  * lib/http: convert options to new style
  * log: convert options to new style
  * serve sftp: convert options to new style
  * serve nfs: convert options to new style
  * serve ftp: convert options to new style
  * serve dlna: convert options to new style
  * cmd/mountlib: convert mount options to new style
  * vfs: convert vfs options to new style
  * vfs: convert time.Duration option to fs.Duration
  * cmd/mountlib: convert time.Duration option to fs.Duration
  * configstruct: skip items with `config:"-"`
  * configstruct: allow parsing of []string encoded as JSON
  * configstruct: make nested config structs work
  * configstruct: fix parsing of invalid booleans in the config
  * fs: check the names and types of the options blocks are correct
  * fs: make Flagger and FlaggerNP interfaces public so we can test flags elsewhere
  * fs: add Options registry and rework rc to use it
  * fs: allow []string to work in Options
  * flags: factor AddFlagsFromOptions from cmd
  * fs: add Groups and FieldName to Option
  * fs: refactor fs.ConfigMap to take a prefix and Options rather than an fs.RegInfo
  * sftp: ignore errors when closing the connection pool
  * sftp: use uint32 for mtime
  * pikpak: optimize file move by removing unnecessary `readMetaData()` call
  * pikpak: fix error with `copyto` command
  * swift: add workarounds for bad listings in Ceph RGW
  * sftp: fix docs on connections not to refer to concurrency
  * docs: remove warp as silver sponsor
  * onedrive: fix nil pointer error when uploading small files
  * vfs: fix fatal error: sync: unlock of unlocked mutex in panics
  * Add Filipe Herculano to contributors
  * Add Thearas to contributors
  * pikpak: implement custom hash to replace wrong sha1
  * pikpak: improves data consistency by ensuring async tasks complete
  * build(deps): bump docker/build-push-action from 5 to 6
  * s3: fix incorrect region for Magalu provider
  * docs: recommend `no_check_bucket = true` for Alibaba - fixes #7889
  * docs: tidy .gitignore for docs
  * docs: fix hugo warning: found no layout file for "html" for kind "term"
  * docs: remove slug and url from command pages since they are no longer needed
  * docs: fix hugo warning: found no layout file for "html" for kind "section"
  * serve dlna: fix panic: invalid argument to Int63n
  * Start v1.68.0-DEV development
* Fri Jun 14 2024 mrueckert@suse.de
- Update to version 1.67.0:
  * Version v1.67.0
  * s3: fix 405 error on HEAD for delete marker with versionId
  * gitannex: make tests run more quietly - use go test -v for more info
  * jottacloud: set metadata on server side copy and move - fixes #7900
  * qingstor: disable integration tests as test account suspended
  * operations: add operations.ReadFile to read the contents of a file into memory
  * fs: make ConfigFs take an fs.Info which makes it more useful
  * touch: fix using -R on certain backends
  * serve s3: fix XML of error message
  * fs/logger: make the tests deterministic
  * zoho: sleep for 60 seconds if rate limit error received
  * zoho: remove simple file names complication which is no longer needed
  * zoho: retry reading info if size wasn't returned
  * zoho: fix throttling problem when uploading files
  * zoho: use cursor listing for improved performance
  * operations: fix hashing problem in integration tests
  * Add Bill Fraser to contributors
  * Add Florian Klink to contributors
  * Add Michał Dzienisiewicz to contributors
  * build(deps): bump github.com/Azure/azure-sdk-for-go/sdk/azidentity
  * pikpak: implement configurable chunk size for multipart upload
  * docs: added info about --progress terminal width
  * pikpak: remove PublicLink from integration tests
  * onedrive: add --onedrive-hard-delete to permanently delete files
  * dropbox: add option to override root namespace
  * tree-wide: replace /bin/bash with /usr/bin/env bash
  * protondrive: don't auth with an empty access token
  * serve s3: fix in-memory metadata storing wrong modtime
  * vfs: fix renaming a directory
  * fstest: make RandomRemoteName shorter
  * googlephotos: remove unnecessary nil check
  * s3, googlecloudstorage, azureblob: fix encoding issue with dir path comparison
  * sync: don't test reading metadata if we can't write it
  * linkbox: ignore TestListDirSorted test until encoding is implemented
  * Add Tomasz Melcer to contributors
  * pikpak: improve upload reliability and resolve potential file conflicts
  * sftp: --sftp-connections to limit maximum number of connections
  * ulozto: fix panic in various integration tests
  * swift: fix integration tester with use_segments_container=false
  * drive: fix tests for backend query command
  * mailru: attempt to fix throttling by decreasing min sleep to 100ms
  * sync: fix expecting SFTP to have MkdirMetadata method: optional feature not implemented
  * operations: fix incorrect modtime on some multipart transfers
  * sync: fix tests on backends which can't have empty directories
  * cache: fix tests when testing for Object.SetMetadata
  * Add Charles Hamilton to contributors
  * Add Thomas Schneider to contributors
  * Add Bruno Fernandes to contributors
  * windows: make rclone work with SeBackupPrivilege and/or SeRestorePrivilege
  * cmd/gitannex: Update command docs
  * cmd/gitannex: Support synonyms of config values
  * S3: Ceph Backend use already exist changed to true (now tested) - fixes #7871
  * s3: Add Magalu S3 Object Storage as provider
  * config: fix default value for description
  * b2: update URLs to new home
  * Add yumeiyin to contributors
  * serve dlna: make BrowseMetadata more compliant - fixes #7883
  * Fix new lint issues reported by golangci-lint v1.59.0
  * docs: fix some comments
  * build: update all dependencies
  * drive: debug when we are ignoring permissions #7853
  * Add Dominik Joe Pantůček to contributors
  * docs: crypt: fix incorrect terminology
  * operations: rework rcat so that it doesn't call the --metadata-mapper twice
  * operations: ensure SrcFsType is set correctly when using --metadata-mapper
  * onedrive: allow setting permissions to fail if failok flag is set
  * Add Evan McBeth to contributors
  * docs: improve readability in faq
  * fs: fix panic when using --metadata-mapper on large google doc files
  * Add JT Olio to contributors
  * Add overallteach to contributors
  * go.mod: update storj.io/uplink to latest release
  * chore: fix function name in comment
  * build: update issue label notification machinery
  * operations: fix missing metadata for multipart transfers to local disk
  * local: implement Object.SetMetadata
  * fs: define the optional interface SetMetadata and implement it in wrapping backends
  * drive: allow setting metadata to fail if failok flag is set
  * cmd/gitannex: When tags do not match, run e2e tests anyway
  * build: Inject rclone version tag when testing
  * cmd/gitannex: Remove assumption in e2e test version check
  * .github/workflows: Install git-annex-remote-rclone on Linux and macOS
  * cmd/gitannex: Add TestEndToEndMigration tests
  * cmd/gitannex: Describe new rclonelayout config in help
  * cmd/gitannex: Drop chdir from e2e tests
  * cmd/gitannex: Repeat TestEndToEnd for all layout modes
  * cmd/gitannex: Refactor e2e tests, add layout compat tests
  * cmd/gitannex: Add support for different layouts
  * cmd/gitannex: Simplify messageParser's finalParameter() func
  * chunker: fix `finalizer already set` error
  * mailru: use --tpslimit 10 on bisync tests
  * bisync: ignore "Implicitly create directory" messages on tests
  * quatrix: fix f.String() not including subpath
  * operations: fix lsjson --encrypted when using --crypt-XXX parameters
  * Add Sunny to contributors
  * Add Michael Terry to contributors
  * serve http: added content-length header when html directory is served
  * docs: minor formatting improvement
  * oauthutil: clear client secret if client ID is set
  * drive: fix description being overwritten on server side moves
  * bump golangci/golangci-lint-action from 4 to 6
  * onedrive: add support for group permissions
  * onedrive: fix references to deprecated permissions properties
  * onedrive: skip writing permissions with 'owner' role
  * build: add issue label notification machinery
  * union: fix deleting dirs when all remotes can't have empty dirs
  * pikpak: improve getFile() usage
  * docs: exit code 9 requires --error-on-no-transfer
  * ulozto: Fix handling of root paths with leading / trailing slashes.
  * fstest: reduce precision of directory time checks on CI
  * sync: remove now superfluous copyEmptyDirectories function
  * sync: fix failed to update directory timestamp or metadata: directory not found
  * sync: fix directory modification times not being set
  * sync: don't need to sync directories if they haven't been modified
  * sync: fix creation of empty directories when --create-empty-src-dirs=false
  * sync: fix management of empty directories to make it more accurate
  * drive: be more explicit in debug when setting permissions fail
  * onedrive,drive: make errors setting permissions into no retry errors
  * docs: add Backblaze as a sponsor
  * storj: update bio on request
  * docs: note that newer linux kernel version is required for ARMv5
  * build: migrate bucket storage for the project to new provider
  * Add hidewrong to contributors
  * swift: implement --swift-use-segments-container to allow >5G files on Blomp
  * random: update Password docs
  * build: add linting for different values of GOOS
  * build: fix linting issues reported by running golangci-lint with different GOOS
  * build: fix linting issues reported by golangci-lint on windows
  * log: fix lint issue SA1019: syscall.Syscall has been deprecated since Go 1.18: Use SyscallN instead.
  * build: run go mod tidy
  * backend http: Adding no-escape flag for option to not escape URL metacharacters in path names - fixes issue #7637
  * bisync: avoid starting tests we don't have time to finish
  * bisync: skip test if config string contains a space
  * fs accounting: Add deleted files total size to status summary line - fixes issue #7190
  * build: remove build constraint syntax for go 1.16 and older
  * build: remove separate go module cache step as its done by setup-go
  * Convert source files with crlf to lf
  * fix spelling
  * bisync: make session path even shorter on tests
  * build: make integration tests run better on macOS and Windows
  * docs: fix heading anchor
  * Add pawsey-kbuckley to contributors
  * Add Katia Esposito to contributors
  * lsjson: small docs change to clarify options
  * genautocomplete: remove Ubuntu-ism from docs and clarify non-root use
  * docs: fix macOS install from source link
  * ncdu: Do not quit on Esc
  * fix: test_all re-running too much stuff
  * Add Dave Nicolson to contributors
  * Add Butanediol to contributors
  * Add yudrywet to contributors
  * docs: Add left and right padding to prevent icon truncation
  * serve s3: fix Last-Modified header format
  * chore: fix function names in comment
  * onedrive: set all metadata permissions and return error summary
  * fs rc: fixes incorrect Content-Type in HTTP API - fixes #7726
  * operations: fix move when dst is nil and fdst is case-insensitive
  * sync: fix case normalisation on s3
  * operations: fix retries downloading too much data with certain backends
  * operations: add more assertions to ReOpen tests to check seek positions
  * Add static-moonlight to contributors
  * doc: add example how to run serve s3
  * serve s3: adjust to move of Mikubill/gofakes3 to rclone/gofakes3
  * Add guangwu to contributors
  * Add jakzoe to contributors
  * Add go mod and sum to gitattributes for consistent line endings
  * bisync: rename extended_char_paths test
  * chunker: fix case-insensitive comparison on local without metadata
  * chunker: fix NewFs when root points to composite multi-chunk file without metadata
  * bisync: more fixes for integration tests
  * bisync: fix endless loop if lockfile decoder errors
  * bisync: make tempDir path shorter
  * fix: close cpu profile
  * docs: fix typo in filtering.md
  * drive: set all metadata permissions and return error summary
  * crypt: fix max suggested length of filenames
  * bisync: fix io.PipeWriter not getting closed on tests
  * pikpak: fix a typo in a comment
  * docs: ensure empty line between text and a following heading
  * .github/workflows: Upgrade deprecated macos-11 to macos-latest
  * cmd/gitannex: Downgrade to protocol version 1
  * cmd/gitannex: Replace e2e test script with Go test
  * docs: clarify option syntax
  * build: fix CVE-2023-45288 by upgrading golang.org/x/net
  * ulozto: remove use of github.com/pkg/errors
  * Add Pieter van Oostrum to contributors
  * docs: fix MANUAL formatting problems
  * backend koofr: remove trailing bracket - fixes #7600
  * webdav: fix SetModTime erasing checksums on owncloud and nextcloud
  * bisync: use fstest.RandomRemote on tests
  * hdfs: fix f.String() not including subpath
  * local: disable unreliable test
  * docs: update warp sponsorship
  * copy: fix nil pointer dereference when corrupted on transfer with nil dst
  * Add Erisa A to contributors
  * Add yoelvini to contributors
  * Add Alexandre Lavigne to contributors
  * test info: improve cleanup of temp files - fixes #7209
  * onedrive: fix --metadata-mapper called twice if writing permissions
  * b2: Add tests for new `cleanup` and `cleanup-hidden` backend commands.
  * rcserver: set `ModTime` for dirs and files served by `--rc-serve`
  * docs: Add R2 note about no_check_bucket
  * s3: add new AWS region il-central-1 Tel Aviv
  * bisync: more fixes for integration tests
  * s3: update Scaleway's configuration options - fixes #7507
  * bisync: several fixes for integration tests
  * ulozto: make password config item be obscured
  * operations: fix very long file names when using copy with --partial
  * Add Warrentheo to contributors
  * Add Alex Garel to contributors
  * onedrive: fix typo
  * config: show more user friendly names of custom types in ui
  * config: add ending period on description option help text
  * docs: add an indication in case of recursive shortcuts in drive
  * ulozto: implement Mover and DirMover interfaces.
  * ulozto: revert the temporary file size limitations
  * ulozto: set Content-Length header if the file size is known.
  * local: fix and update -l docs
  * serve webdav: fix webdav with --baseurl under Windows
  * memory: fix incorrect list entries when rooted at subdirectory
  * memory: fix deadlock in operations.Purge
  * bisync: add to integration tests - fixes #7665
  * memory: fix dst mutating src after server-side copy
  * mount,cmount,mount2: add --direct-io flag to force uncached access
  * vfs: fix download loop when file size shrunk
  * local: add --local-time-type to use mtime/atime/btime/ctime as the time
  * Add psychopatt to contributors
  * docs: remove email from authors
  * rc: fix stats groups being ignored in operations/check
  * drive: fix server side copy with metadata from my drive to shared drive
  * drive: stop sending notification emails when setting permissions
  * Add iotmaestro to contributors
  * Add Vitaly to contributors
  * Add hoyho to contributors
  * Add Lewis Hook to contributors
  * Add a new backend for uloz.to
  * cmd/gitannex: Add the gitannex subcommand
  * linkbox: fix list paging and optimized synchronization.
  * linkbox: fix working with names longer than 8-25 Unicode chars.
  * b2: Add new `cleanup` and `cleanup-hidden` backend commands.
  * s3: validate CopyCutoff size before copy
  * Improve error messages when objects have been corrupted on transfer - fixes #5268
  * onedrive: fix "unauthenticated: Unauthenticated" errors when downloading
  * lib/rest: Add Client.Do function to call http.Client.Do
  * lib/rest: add CheckRedirect function for redirect management
  * operations: Fix "optional feature not implemented" error with a crypted sftp
  * Add Kyle Reynolds to contributors
  * Add YukiUnHappy to contributors
  * Add Gachoud Philippe to contributors
  * Add racerole to contributors
  * Add John-Paul Smith to contributors
  * onedrive: make server-side copy to work in more scenarios
  * docs: Proton Drive, correct typo
  * docs: drive: corrected relative path of scopes to absolute
  * docs: clarify `shell_type = none` and `ssh = ` behaviour
  * fs: improve JSON Unmarshalling for Duration
  * docs: remove repeated words
  * owncloud: add config owncloud_exclude_mounts which allows to exclude mounted folders when listing remote resources
  * drive: backend query command
  * Start v1.67.0-DEV development
* Thu May 30 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Remove %%go_nostrip, not necessary and bloats the binary
* Sat Mar 16 2024 John Kizer john.kizer@proton.me
- Update to version 1.66.0:
  * Directory modification times and metadata synced for supported backends
  * Many updates to bisync command options, operation and presentation
  * Description field added for all backends
  * amazonclouddrive: remove backend
  * build: Update to go1.22, go1.20 is minimum required
  * build: CVE-2024-24786 addressed via protobuf upgrade
  * check: Respect --no-unicode-normalization and --ignore-case-sync for --checkfile
  * cmd: Improved shell auto completion reduces size of the completion file and works faster
  * fs: Add more detailed logging for file includes/excludes
  * lsf: Add --time-format flag, make metadata appear for directories
  * lsjson: Make metadata appear for directories (Nick Craig-Wood)
  * rc: Add srcFs and dstFs to core/stats and core/transferred stats,
  * rc: Add operations/hashsum to the rc as rclone hashsum equivalent,
  * rc: Add config/paths to the rc as rclone config paths equivalent
  * sync: Optionally report list of synced paths to file
  * sync: Implement directory sync for mod times and metadata
  * sync: Don't set directory modtimes if already set
  * sync: Don't sync directory modtimes from backends which don't have directories
  * backend: Make backends which use oauth implement the Shutdown and shutdown the oauth properly
  * bisync: Handle unicode and case normalization consistently
  * bisync: Partial uploads known issue on local/ftp/sftp has been resolved (unless using --inplace)
  * bisync: Fixed handling of unicode normalization and case insensitivity, support for relevant flags
  * bisync: No longer fails to find the correct listing file when configs are overridden with backend-specific flags
  * nfsmount: Fix exit after external unmount, fix --volname being ignored
  * operations: Fix case-insensitive moves in operations.Move
  * operations: Fix TestCaseInsensitiveMoveFileDryRun on chunker integration tests
  * operations: Fix TestMkdirModTime test
  * operations: Fix TestSetDirModTime for backends with SetDirModTime but not Metadata
  * operations: Fix typo in log messages
  * serve restic: Fix error handling
  * serve webdav: Fix --baseurl without leading /
  * stats: Fix race between ResetCounters and stopAverageLoop called from time.AfterFunc
  * sync: --fix-case flag to rename case insensitive dest
  * sync: Use operations.DirMove instead of sync.MoveDir for --fix-case
  * systemd: Fix detection and switch to the coreos package everywhere rather than having 2 separate libraries
  * mount: Notice daemon dying much quicker
  * Numerous backend-specific updates detailed at https://rclone.org/changelog/#v1-66-0-2024-03-10
* Thu Jan 25 2024 mrueckert@suse.de
- Update to version 1.65.2:
  * Version v1.65.2
  * azureblob: fix data corruption bug #7590
  * build: add -race flag to integration tester test_all
  * docs: add bisync to index
  * build(deps): bump actions/cache from 3 to 4
  * add missing backtick
  * docs: add rclone OS requirements
  * imagekit: updated overview - supported operations
  * imagekit: Updated docs and web content
  * docs: add warp.dev sponsorship to github home page
  * docs: add warp.dev as a sponsor
  * docs: update website footer
  * vfs: fix stale data when using --vfs-cache-mode full
  * build(deps): bump github.com/cloudflare/circl from 1.3.6 to 1.3.7
  * Start v1.65.2-DEV development
* Mon Jan  8 2024 mrueckert@suse.de
- Update to version 1.65.1:
  * Version v1.65.1
  * docs: Fix broken test_proxy.py link again
  * operations: fix files moved by rclone move not being counted as transfers
  * accounting: fix stats to show server side transfers
  * onedrive: fix "unauthenticated: Unauthenticated" errors when uploading
  * Revert "mount: fix macOS not noticing errors with --daemon"
  * s3: fix crash if no UploadId in multipart upload
  * serve s3: fix listing oddities
  * protondrive: fix CVE-2023-45286 / GHSA-xwh9-gc39-5298
  * build: fix docker build on arm/v6
  * build(deps): bump golang.org/x/crypto to fix ssh terrapin CVE-2023-48795
  * oauthutil: avoid panic when `*token` and `*ts.token` are the same
  * ftp: fix multi-thread copy
  * googlephotos: fix nil pointer exception when batch failed
  * hasher: fix invalid memory address error when MaxAge == 0
  * docs/librclone: the newer and recommended ucrt64 subsystem of msys2 can now be used for building on windows
  * docs: fix broken link in serve webdav
  * azure-files: fix storage base url
  * oracle object storage: fix object storage endpoint for custom endpoints
  * chunker,compress,crypt,hasher,union: fix rclone move a file over itself deleting the file
  * docs: fix broken link
  * dropbox: fix used space on dropbox team accounts
  * vfs: note that --vfs-refresh runs in the background #6830
  * docs: update contributor email
  * build(deps): bump actions/setup-go from 4 to 5
  * Doc change: Add the CreateBucket permission requirement for AWS S3
  * nfsmount: compile for all unix oses, add --sudo and fix error/option handling
  * serve nfs: Mark as experimental
  * onedrive: fix error listing: unknown object type <nil>
  * docs: fix typo in docs.md
  * multipart copy create bucket if it doesn't exist.
  * smb: fix shares not listed by updating go-smb2
  * mount: fix macOS not noticing errors with --daemon
  * install.sh: fix harmless error message on install
  * Start v1.65.1-DEV development
* Sun Nov 26 2023 mrueckert@suse.de
- Update to version 1.65.0:
  * Version v1.65.0
  * onedrive: add --onedrive-delta flag to enable ListR
  * smb: fix modtime of multithread uploads by setting PartialUploads
  * smb: fix about size wrong by switching to github.com/cloudsoda/go-smb2/ fork
  * serve s3: fix overwrite of files with 0 length file
  * serve s3: fix error handling for listing non-existent prefix - fixes #7455
  * test_all: make integration test for serve s3
  * Add Abhinav Dhiman to contributors
  * Add 你知道未来吗 to contributors
  * imagekit: Added ImageKit backend
  * fs/fshttp: fix --contimeout being ignored
  * s3: ensure we can set upload cutoff that we use for Rclone provider
  * serve s3: document multipart copy doesn't work #7454
  * b2: fix streaming chunked files an exact multiple of chunk size
  * fstest: factor chunked streaming tests from b2 and use in all backends
  * b2: fix server side chunked copy when file size was exactly --b2-copy-cutoff
  * fstest: factor chunked copy tests from b2 and use them in s3 and oos
  * operations: fix overwrite of destination when multi-thread transfer fails
  * random: stop using deprecated rand.Seed in go1.20 and later
  * random: speed up String function for generating larger blocks
  * hash: allow runtime configuration of supported hashes for testing
  * Add Alen Šiljak to contributors
  * http: enable methods used with WebDAV - fixes #7444
  * s3: detect looping when using gcs and versions
  * dropbox: fix missing encoding for rclone purge again
  * test_all: limit the Zoho tests to just the backend
  * test_all: remove uptobox from integration tests
  * operations: use less memory when doing multithread uploads
  * operations: make Open() return an io.ReadSeekCloser #7350
  * fs: add ChunkWriterDoesntSeek feature flag and set it for b2
  * mockobject: fix SetUnknownSize method to obey parameter passed in
  * box: fix performance problem reading metadata for single files
  * gcs: fix 400 Bad request errors when using multi-thread copy
  * http: implement set backend command to update running backend
  * dropbox: fix missing encoding for rclone purge
  * Update Docs to show SMB remote supports modtime.md
  * docs: cleanup backend hashes sections
  * docs: replace mod-time with modtime
  * march: Fix excessive parallelism when using --no-traverse
  * Add Mina Galić to contributors
  * Makefile: use POSIX compatible install arguments
  * install.sh: Clean up temp files in install script
  * drive: fix integration tests by enabling metadata support from the context
  * fstests: make sure Metadata is enabled in the context for metadata tests
  * Refresh CONTRIBUTING.md
  * fs: implement --metadata-mapper to transform metatadata with a user supplied program
  * drive: fix error updating created time metadata on existing object
  * drive: add read/write metadata support
  * Add moongdal to contributors
  * Add viktor to contributors
  * Add karan to contributors
  * Add Oksana Zhykina to contributors
  * linkbox: pre-merge fixes
  * backend: add Linkbox backend
  * vfs: error out early if can't upload 0 length file
  * azurefiles: finish docs and implementation and add optional interfaces
  * Implement Azure Files backend
  * fs: fix a typo in a comment
  * quatrix: overwrite files on conflict during server-side move
  * quatrix: add partial upload support
  * serve s3: pre-merge tweaks
  * Add Saw-jan to contributors
  * serve s3: fixes before merge
  * Add Artur Neumann to contributors
  * serve s3: fix file name encoding using s3 serve with mc client
  * Add Mikubill to contributors
  * serve s3: let rclone act as an S3 compatible server
  * s3: add --s3-disable-multipart-uploads flag
  * bin/update_authors.py: add authors from Co-authored-by: lines too
  * size: dont show duplicate object count when less than 1k
  * lib/file: fix MkdirAll after go1.21.4 stdlib update
  * docs: factor large docs into separate .md files to make them easier to maintain.
  * Add Tayo-pasedaRJ to contributors
  * Add Adithya Kumar to contributors
  * Add wuxingzhong to contributors
  * hdfs: added support for list of namenodes in hdfs remote config
  * webdav: added an rclone vendor to work with rclone serve webdav
  * docs: show hashsum arguments as optional in usage string
  * docs: document how to build with version info and icon resources on windows
  * build: refactor version info and icon resource handling on windows
  * serve dnla: fix crash on graceful exit
  * operations: fix server side copies on partial upload backends after refactor
  * mount: disable mount for freebsd
  * build: update all dependencies
  * operations: fix invalid UTF-8 when truncating file names when not using --inplace
  * operations: refactor Copy into methods on an temporary object
  * operations: factor Copy into its own file
  * build(deps): bump google.golang.org/grpc from 1.56.2 to 1.56.3
  * b2: fix multi-thread upload with copyto going to wrong name
  * fstests: add integration test for OpenChunkWriter uploading to the wrong name
  * b2: fix error handler to remove confusing DEBUG messages
  * s3: emit a debug message if anonymous credentials are in use
  * ncdu: fix crash when re-entering changed directory after rescan
  * fs: fix docs for Bits
  * fs: add IsSet convenience method to Bits
  * docs: remove third party logos from source tree
  * docs: update Storj image and link
  * Add alfish2000 to contributors
  * union: fix documentation
  * build: fix new lint errors with golangci-lint v1.55.0
  * selfupdate: make sure we don't run tests if selfupdate is set
  * local: fix copying from Windows Volume Shadows
  * Changelog updates from Version 1.64.2
  * selfupdate: fix "invalid hashsum signature" error
  * build: add the serve docker tests to the integration tester
  * build: fix docker build running out of space
  * Add Ivan Yanitra to contributors
  * Add Keigo Imai to contributors
  * Add Gabriel Espinoza to contributors
  * azureblob: add support cold tier
  * drive: add a note that --drive-scope accepts comma-separated list of scopes
  * docs: change authors email for SimJoSt
  * Changelog updates from Version 1.64.1
  * lib/http: export basic go strings functions
  * docs: update documentation for --fast-list adding info about ListR
  * mount: fix automount not detecting drive is ready
  * sftp: implement --sftp-copy-is-hardlink to server side copy as hardlink
  * serve sftp: return not supported error for not supported commands
  * b2: fix chunked streaming uploads
  * build: upgrade golang.org/x/net to v0.17.0 to fix HTTP/2 rapid reset
  * b2: fix server side copies greater than 4GB
  * cmd: Make --progress output logs in the same format as without
  * operations: fix error message on delete to have file name - fixes #7355
  * operations: fix OpenOptions ignored in copy if operation was a multiThreadCopy
  * build: fix docker beta build running out of space
  * Add Volodymyr to contributors
  * operations: implement --partial-suffix to control extension of temporary file names
  * s3: fix no error being returned when creating a bucket we don't own
  * oracleobjectstorage: fix OpenOptions being ignored in uploadMultipart with chunkWriter
  * s3: fix OpenOptions being ignored in uploadMultipart with chunkWriter
  * drive: add --drive-show-all-gdocs to allow unexportable gdocs to be server side copied
  * Add Saleh Dindar to contributors
  * Add Beyond Meat to contributors
  * nfsmount: documentation for new NFS mount feature for macOS
  * nfsmount: New mount command to provide mount mechanism on macOS without FUSE
  * serve nfs: new `serve nfs` command
  * vfs: Add go-billy dependency and make sure vfs.Handle implements billy.File
  * vfs: [bugfix] Update dir modification time
  * vfs: [bugfix] Implement Name() method in WriteFileHandle and ReadFileHandle
  * vfs: add --vfs-refresh flag to read all the directories on start
  * operations: add operations/check to the rc API
  * operations: close file in TestUploadFile test so it can be deleted on Windows
  * googlephotos: implement batcher for uploads - fixes #6920
  * dropbox: factor batcher into lib/batcher
  * fs: re-implement DumpMode with Bits
  * fs: create fs.Bits for easy creation of parameters from a bitset of choices
  * vfs: re-implement CacheMode with fs.Enum
  * fs: re-implement CutoffMode, LogLevel, TerminalColorMode with Enum
  * fs: create fs.Enum for easy creation of parameters from a list of choices
  * fs: fix option types printing incorrectly for backend flags
  * onedrive: implement ListR method which gives --fast-list support
  * onedrive: factor API types back into correct file
  * b2: reduce default --b2-upload-concurrency to 4 to reduce memory usage
  * b2: fix locking window when getting mutipart upload URL
  * pacer: fix b2 deadlock by defaulting max connections to unlimited
  * docs: add utime (time of file upload) to standard system metadata
  * jottacloud: add support for reading and writing metadata
  * s3: fix slice bounds out of range error when listing
  * Add rinsuki to contributors
  * drive: add support of SHA-1 and SHA-256 checksum
  * s3: add docs on how to add a new provider
  * s3: add Linode provider
  * s3: Factor providers list out and auto generate textual version
  * docs: fix backend doc generator to not output duplicate config names
  * Add Nikita Shoshin to contributors
  * rcserver: set `Last-Modified` header for files served by `--rc-serve`
  * docs: fix typos found by codespell in docs and code comments
  * onedrive: fix the configurator to allow /teams/ID in the config
  * build: add btesth target to output beta log in HTML for email pasting
  * lsjson: make sure we set the global metadata flag too
  * rc: always report an error as JSON
  * b2: fix multipart upload: corrupted on transfer: sizes differ XXX vs 0
  * b2: implement --b2-lifecycle to control lifecycle when creating buckets
  * b2: implement "rclone backend lifecycle" to read and set bucket lifecycles
  * b2: fix listing all buckets when not needed
  * azureblob: fix "fatal error: concurrent map writes"
  * build(deps): bump docker/setup-qemu-action from 2 to 3
  * box: add more logging for polling
  * box: filter more EventIDs when polling
  * build(deps): bump docker/setup-buildx-action from 2 to 3
  * storj: update storj.io/uplink to v1.12.0
  * docs: add notes on how to update the website between releases
  * docs: remove minio sponsor box for the moment
  * docs: update Storj partner link
  * Add Herby Gillot to contributors
  * Add Pat Patterson to contributors
  * docs: add MacPorts install info
  * build(deps): bump docker/metadata-action from 4 to 5
  * build(deps): bump docker/login-action from 2 to 3
  * build(deps): bump docker/build-push-action from 4 to 5
  * fix overview of oracle object storage as it supports multithreaded
  * operations: ensure concurrency is no greater than the number of chunks - fixes #7299
  * docs: fix minimum Go version and update to 1.18
  * Start v1.65.0-DEV development
* Thu Oct 19 2023 mrueckert@suse.de
- Update to version 1.64.2:
  * Version v1.64.2
  * selfupdate: fix "invalid hashsum signature" error
  * build: fix docker build running out of space
  * Start v1.64.2-DEV development
* Thu Oct 19 2023 Marcus Rueckert <mrueckert@suse.de>
- switch services to manual according to the new guidelines
* Tue Oct 17 2023 mrueckert@suse.de
- Update to version 1.64.1:
  * Version v1.64.1
  * mount: fix automount not detecting drive is ready
  * serve sftp: return not supported error for not supported commands
  * b2: fix chunked streaming uploads
  * build: upgrade golang.org/x/net to v0.17.0 to fix HTTP/2 rapid reset
  * b2: fix server side copies greater than 4GB
  * cmd: Make --progress output logs in the same format as without
  * operations: fix error message on delete to have file name - fixes #7355
  * operations: fix OpenOptions ignored in copy if operation was a multiThreadCopy
  * build: fix docker beta build running out of space
  * oracleobjectstorage: fix OpenOptions being ignored in uploadMultipart with chunkWriter
  * s3: fix OpenOptions being ignored in uploadMultipart with chunkWriter
  * vfs: [bugfix] Update dir modification time
  * operations: close file in TestUploadFile test so it can be deleted on Windows
  * b2: reduce default --b2-upload-concurrency to 4 to reduce memory usage
  * b2: fix locking window when getting mutipart upload URL
  * pacer: fix b2 deadlock by defaulting max connections to unlimited
  * s3: fix slice bounds out of range error when listing
  * docs: fix backend doc generator to not output duplicate config names
  * docs: fix typos found by codespell in docs and code comments
  * onedrive: fix the configurator to allow /teams/ID in the config
  * lsjson: make sure we set the global metadata flag too
  * b2: fix multipart upload: corrupted on transfer: sizes differ XXX vs 0
  * azureblob: fix "fatal error: concurrent map writes"
  * build(deps): bump docker/setup-qemu-action from 2 to 3
  * build(deps): bump docker/setup-buildx-action from 2 to 3
  * storj: update storj.io/uplink to v1.12.0
  * docs: add notes on how to update the website between releases
  * docs: remove minio sponsor box for the moment
  * docs: update Storj partner link
  * docs: add MacPorts install info
  * build(deps): bump docker/metadata-action from 4 to 5
  * build(deps): bump docker/login-action from 2 to 3
  * build(deps): bump docker/build-push-action from 4 to 5
  * fix overview of oracle object storage as it supports multithreaded
  * operations: ensure concurrency is no greater than the number of chunks - fixes #7299
  * Start v1.64.1-DEV development
* Tue Oct  3 2023 info@paolostivanin.com
- Update to version 1.64.0:
  * protondrive: make cached keys rclone style and not show with `rclone config redacted`
  * docs: document release signing and verification
  * docs: fix typo in rc docs - fixes #7287
  * protondrive: complete docs with all references to Proton Drive
  * drive: add --drive-fast-list-bug-fix to control ListR bug workaround
  * s3: add rclone backend restore-status command
  * Add Drew Stinnett to contributors
  * Add David Pedersen to contributors
  * rc: Add operations/settier to API
  * protondrive: implement two-password mode (#7279)
  * vfs: Update parent directory modtimes on vfs actions
  * hdfs: fix retry "replication in progress" errors when uploading
  * hdfs: fix uploading to the wrong object on Update with overriden remote name
  * test_all: remove filefabric from integration tests
  * Add Oksana and Volodymyr Kit to contributors
  * quatrix: add backend to support Quatrix
  * protondrive: fix signature verification logic by accounting for legacy signing scheme (#7278)
  * vfs: add --vfs-cache-min-free-space to control minimum free space on the disk containing the cache
  * rc: add core/du to measure local disk usage
  * Add lib/diskusage to measure used/free on disks
  * Add zjx20 to contributors
  * local: rmdir return an error if the path is not a dir
  * s3: implement backend set command to update running config
  * protondrive: improves 2fa and draft error messages (#7280)
  * zoho: remove Range requests workarounds to fix integration tests
  * fstests: fix PublicLink failing on storj
  * opendrive: fix List on a just deleted and remade directory
  * operations: fix TestCopyFileMaxTransfer test to not be quite so fussy
  * compress: fix ChangeNotify
  * azureblob: fix purging with directory markers
  * test_all: ignore Rmdirs test failure on b2 as it fails because of versions
  * Add @nielash as bisync maintainer
  * build(deps): bump actions/checkout from 3 to 4
  * bisync: fix dryRun rc parameter being ignored
  * bisync: add rc parameters for new flags
  * compress: fix integration tests by adding missing OpenChunkWriter exclude
  * cache: fix integration tests by adding missing OpenChunkWriter exclude
  * cmd: refactor and use sysdnotify in more commands
  * box: add --box-impersonate to impersonate a user ID - fixes #7267
  * union: add :writback to act as a simple cache
  * azureblob: fix creation of directory markers
  * fstest: fix sftp ssh integration tests
  * b2: fix ChunkWriter size return
  * s3: fix multpart streaming uploads of 0 length files
  * backends: change OpenChunkWriter interface to allow backend concurrency override
  * Add Alishan Ladhani to contributors
  * b2: fix rclone link when object path contains special characters
  * serve dlna: fix MIME type if backend can't identify it
  * docs: add Storj as a sponsor
  * Add Bjørn Smith to contributors
  * jotta: added Telia Sky whitelabel (Norway)
  * docs: single character remote names in Windows
  * docs: sftp: add note regarding format of server_command
  * fshttp: fix --bind 0.0.0.0 allowing IPv6 and --bind ::0 allowing IPv4
  * box: fix unhelpful decoding of error messages into decimal numbers
  * cmd/ncdu: fix add keybinding to rescan filesystem
  * box: add polling support
  * cmd/ncdu: add keybinding to rescan filesystem
  * docs: may not -> might not, to remove ambiguity
  * build: fix lint errors when re-enabling revive var-naming
  * build: fix lint errors when re-enabling revive exported & package-comments
  * build: re-enable revive linters
  * lib/multipart: fix accounting for multipart transfers
  * s3: fix purging of root directory with --s3-directory-markers - fixes #7247
  * fstests: add backend integration test for purging root directory #7247
  * s3: fix accounting for multpart uploads
  * oracleobjectstorage: fix accounting for multpart uploads
  * b2: fix accounting for multpart uploads
  * operations: fix terminology in multi-thread copy
  * operations: fix accounting for multi-thread transfers
  * operations: don't buffer when a backend implements OpenWriterAt
  * lib/pool: add DelayAccounting() to fix accounting when reading hashes
  * lib/pool: add SetAccounting to RW
  * oracleobjectstorage: implement OpenChunkWriter and multi-thread uploads #7056
  * b2: implement OpenChunkWriter and multi-thread uploads #7056
  * azureblob: implement OpenChunkWriter and multi-thread uploads #7056
  * operations: document multi-thread copy and tweak defaults
  * operations: add abort on exit to multithread copy
  * operations: multipart: don't buffer transfers to local disk #7056
  * s3: factor generic multipart upload into lib/multipart #7056
  * fs: add context.Ctx to ChunkWriter methods
  * operations: fix and tidy multithread code
  * s3: fix retry logic, logging and error reporting for chunk upload
  * fs: introduces aliases for OpenWriterAtFn and OpenChunkWriterFn
  * pool: add page backed reader/writer for multi thread uploads
  * lib/readers: add NoSeeker to adapt io.Reader to io.ReadSeeker
  * serve ftp: fix race condition when using the auth proxy
  * docs: remove contributor's old email
  * serve ftp: update to goftp.io/server v2.0.1 - fixes #7237
  * serve sftp: fix hash calculations with --vfs-cache-mode full
  * Add Roberto Ricci to contributors
  * vfs: make sure struct field is aligned for atomic access
  * vfs: use atomic types
  * lib: use atomic types
  * fs: use atomic types
  * cmount: use atomic types
  * smb: use atomic types
  * sftp: use atomic types
  * seafile: use atomic types
  * local: use atomic types
  * filefabric: use atomic types
  * box: use atomic types
  * union: use atomic types
  * sftp: fix --sftp-ssh looking for ssh agent - fixes #7235
  * sftp: fix spurious warning when using --sftp-ssh
  * sync: fix lockup with --cutoff-mode=soft and --max-duration
  * ftp: fix 425 "TLS session of data connection not resumed" errors
  * rmdirs: remove directories concurrently controlled by --checkers
  * Add hideo aoyama to contributors
  * Add Jacob Hands to contributors
  * build: add snap installation
  * ci: change Winget Releaser job to `ubuntu-latest`
  * fs: Fix transferTime not being set in JSON logs
  * fs: Don't stop calculating average transfer speed until the operation is complete
  * sync: fix erroneous test in TestSyncOverlapWithFilter
  * Add Vitor Gomes to contributors
  * Add nielash to contributors
  * Add alexia to contributors
  * multithread: refactor multithread operation to use OpenChunkWriter if available #7056
  * config: add "multi-thread-chunk-size" flag #7056
  * s3: refactor MultipartUpload to use OpenChunkWriter and ChunkWriter #7056
  * features: add new interfaces OpenChunkWriter and ChunkWriter #7056
  * bisync: typo corrections & other doc improvements
  * bisync: Add support for --create-empty-src-dirs - Fixes #6109
  * bisync: Add experimental --resilient mode to allow recovery from self-correctable errors
  * bisync: Add new --ignore-listing-checksum flag to distinguish from --ignore-checksum
  * bisync: equality check before renaming (leave identical files alone)
  * bisync: apply filters correctly during deletes
  * bisync: enforce --check-access during --resync
  * bisync: dry runs no longer commit filter changes
  * gitignore: add .DS_Store and remove *.log
  * fichier: fix error code parsing
  * build: update to released go1.21
  * Add antoinetran to contributors
  * Add James Braza to contributors
  * Add Masamune3210 to contributors
  * Add Nihaal Sangha to contributors
  * protondrive: update the information regarding the advance setting enable_caching (#7202)
  * docs: clarify --checksum documentation - Fixes #7145
  * docs: add some more docs on making your own backend
  * docs: environment variable remote name only supports letters, digits, or underscores
  * docs: local: fix typo
  * lib/rest: remove unnecessary nil check
  * drive: fix typo in docs
  * oracleobjectstorage: Use rclone's rate limiter in mutipart transfers
  * accounting: show server side stats in own lines and not as bytes transferred
  * rclone test info: add --check-base32768 flag to check can store all base32768 characters
  * Add Raymond Berger to contributors
  * storj: performance improvement for large file uploads
  * docs: box client_id creation
  * docs: add missing comma to overview webdav footnote
  * build: update to go1.21rc4
  * Add Julian Lepinski to contributors
  * docs: add minio as a sponsor
  * swift: fix HEADing 0-length objects when --swift-no-large-objects set
  * docs: update command docs to new style
  * docs: group the global flags and make them appear on command and flags pages
  * Add rclone completion powershell - basic implementation only
  * docs: fix rclone config edit docs
  * build: remove unused package cmd/serve/http/data
  * Add nielash to contributors
  * Add Zach to contributors
  * http: fix webdav OPTIONS response (#6433)
  * webdav: nextcloud: fix segment violation in low-level retry
  * sftp: support dynamic --sftp-path-override
  * ftp,sftp: add socks_proxy support for SOCKS5 proxies
  * http: CORS should not be send if not set (#6433)
  * docs: rclone backend restore
  * build: update dependencies
  * Add yuudi to contributors
  * rc: add execute-id for job-id
  * sftp: add --sftp-ssh to specify an external ssh binary to use
  * Add Niklas Hambüchen to contributors
  * protondrive: fix a bug in parsing User metadata (#7174)
  * docs: dropbox: Explain that Teams needs "Full Dropbox"
  * fichier: implement DirMove
  * docs: b2 versions names caveat
  * serve webdav: fix error: Expecting fs.Object or fs.Directory, got <nil>
  * docs: s3 versions names caveat
  * http servers: allow CORS to be set with --allow-origin flag - fixes #5078
  * sftp: stop uploads re-using the same ssh connection to improve performance
  * vfs: keep virtual directory status accurate and reduce deadlock potential
  * vfs: Added cache cleaner for directories to reduce memory usage
  * Add Edwin Mackenzie-Owen to contributors
  * Add Tiago Boeing to contributors
  * Add gabriel-suela to contributors
  * Add Ricardo D'O. Albanus to contributors
  * smb: implement multi-threaded writes for copies to smb
  * docs: mega: update with solution when receiving killed on process
  * protondrive: fix download signature verification bug (#7169)
  * protondrive: fix bug in digests parsing (#7164)
  * protondrive: fix missing file sha1 and appstring issues (#7163)
  * Add Chun-Hung Tseng to Maintainer (#7162)
  * cmd: fix log message typo
  * chunker: Update documentation to mention issue with small files
  * fix: mount parsing for linux
  * Add Chun-Hung Tseng to contributors
  * protondrive: add protondrive backend - fixes #6072
  * doc: Fix Leviia block
  * docs: mention Box as base32768 compatible
  * Add Leviia Object Storage on index.md
  * Add Object storage to Leviia on README.md
  * --max-transfer - add new exit code (10)
  * Changelog updates from Version v1.63.1
  * build: add new sponsors page to docs
  * operations: fix overlapping check on case insensitive file systems
  * Add Benjamin to contributors
  * s3: add Leviia S3 Object Storage as provider
  * build: update to go1.21rc3 and make go1.19 the minimum required version
  * Add darix to contributors
  * box: fix reconnect failing with HTTP 400 Bad Request
  * webdav: nextcloud chunking: add more guidance for the user to check the config
  * operations: fix .rclonelink files not being converted back to symlinks
  * local: fix partial directory read for corrupted filesystem
  * smb: fix "Statfs failed: bucket or container name is needed" when mounting
  * Add Vladislav Vorobev to contributors
  * docs: no need to disable 2FA for Mail.ru Cloud anymore
  * rclone config redacted: implement support mechanism for showing redacted config
  * docs: update the number of providers supported
  * Add Mahad to contributors
  * Add BakaWang to contributors
  * docs: drive: Fix step 4 in "Making your own client_id"
  * s3: add synology to s3 provider list
  * docs: remove old donate page
  * docs: update contact page on website
  * webdav: nextcloud: fix must use /dav/files/USER endpoint not /webdav error
  * operations: fix deadlock when using lsd/ls with --progress - Fixes #7102
  * dirtree: fix performance with large directories of directories and --fast-list
  * Add Fjodor42 to contributors
  * Add Dean Attali to contributors
  * Add Sawada Tsunayoshi to contributors
  * jottacloud: add Onlime provider
  * build: fix macos builds for versions < 12
  * docs: dropbox get client id, clarify you need to click a button
* Thu Jul 20 2023 mrueckert@suse.de
- Update to version 1.63.1:
  * Version v1.63.1
  * build: add new sponsors page to docs
  * Start v1.63.1-DEV development
  * docs: no need to disable 2FA for Mail.ru Cloud anymore
  * box: fix reconnect failing with HTTP 400 Bad Request
  * webdav: nextcloud chunking: add more guidance for the user to check the config
  * operations: fix .rclonelink files not being converted back to symlinks
  * local: fix partial directory read for corrupted filesystem
  * smb: fix "Statfs failed: bucket or container name is needed" when mounting
  * docs: drive: Fix step 4 in "Making your own client_id"
  * docs: update the number of providers supported
  * docs: remove old donate page
  * webdav: nextcloud: fix must use /dav/files/USER endpoint not /webdav error
  * docs: update contact page on website
  * operations: fix deadlock when using lsd/ls with --progress - Fixes #7102
  * dirtree: fix performance with large directories of directories and --fast-list
  * build: fix macos builds for versions < 12
  * docs: dropbox get client id, clarify you need to click a button
  * docs: website: replace google analytics with plausible analytics
  * docs: rename donate page to sponsor page and rework
  * docs: fixed typo in exclude example in filtering docs (#7097)
- drop fix-nextcloud-chunked.patch:
  included in update
* Fri Jul  7 2023 Marcus Rueckert <mrueckert@suse.de>
- Avoid duplication in the %%build section for the pie ppc64 case.
  Just use line continuation for the build cmdline and %%ifnarch
  ppc64 to enable pie mode on everything but ppc64
* Fri Jul  7 2023 Marcus Rueckert <mrueckert@suse.de>
- Fix the rclone version update by properly setting  the package
  variable during the build
* Fri Jul  7 2023 Marcus Rueckert <mrueckert@suse.de>
- added fix-nextcloud-chunked.patch:
  The patch is a slightly modified version of
  73d1b72bd759f838ad322b42e75111652eafe02e, which should give the
  user more guidance to check the configuration.
  This should fix https://github.com/rclone/rclone/issues/7103
* Thu Jul  6 2023 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.63.0:
  * New backends
  - Pikpak
  - New S3 providers
    + petabox.io
    + Google Cloud Storage
  - New WebDAV providers
    + Fastmail
  * Major changes
  - Files will be copied to a temporary name ending in `.partial` when copying to `local`, `ftp`,
    `sftp` then renamed at the end of the transfer.
    + This helps with data integrity as we don't delete the existing file until the new one is
    complete.
    + It can be disabled with the --inplace flag.
    + This behaviour will also happen if the backend is wrapped, for example `sftp` wrapped with
    `crypt`.
  - The s3, azureblob and gcs backends now support directory markers so empty directories are
    supported
  - The --default-time flag now controls the unknown modification time of files/dirs
    + If a file or directory does not have a modification time rclone can read then rclone will
    display this fixed time instead.
    + For the old behaviour use `--default-time 0s` which will set this time to the time rclone
    started up.
  * New Features
  - build
    + Modernise linters in use and fixup all affected code
    + Push docker beta to GHCR (GitHub container registry)
  - cat: Add `--separator` option to cat command
  - config
    + Do not remove/overwrite other files during config file save
    + Do not overwrite config file symbolic link
    + Stop `config create` making invalid config files
  - doc updates
  - fs
    + Add `size` to JSON logs when moving or copying an object
    + Allow boolean features to be enabled with `--disable !Feature`
  - genautocomplete: Rename to `completion` with alias to the old name
  - librclone: Added example on using `librclone` with Go
  - lsjson: Make `--stat` more efficient
  - operations
    + Implement `--multi-thread-write-buffer-size` for speed improvements on downloads
    + Reopen downloads on error when using `check --download` and `cat`
  - rc: `config/listremotes` includes remotes defined with environment variables
  - selfupdate: Obey `--no-check-certificate` flag
  - serve restic: Trigger systemd notify
  - serve webdav: Implement owncloud checksum and modtime extensions
  - sync: `--suffix-keep-extension` preserve 2 part extensions like .tar.gz
  * Bug Fixes
  - accounting
    + Fix Prometheus metrics to be the same as `core/stats`
    + Bwlimit signal handler should always start
  - bisync: Fix `maxDelete` parameter being ignored via the rc
  - cmd/ncdu: Fix screen corruption when logging
  - filter: Fix deadlock with errors on `--files-from`
  - fs
    + Fix interaction between `--progress` and `--interactive`
    + Fix infinite recursive call in pacer ModifyCalculator (fixes issue reported by
    the staticcheck linter)
  - lib/atexit: Ensure OnError only calls cancel function once
  - lib/rest: Fix problems re-using HTTP connections
  - rc
    + Fix `operations/stat` with trailing `/`
    + Fix missing `--rc` flags
    + Fix output of Time values in `options/get`
  - serve dlna: Fix potential data race
  - version: Fix reported os/kernel version for windows
  * Mount
  - Add `--mount-case-insensitive` to force the mount to be case insensitive
  - Removed unnecessary byte slice allocation for reads
  - Clarify rclone mount error when installed via homebrew
  - Added _netdev to the example mount so it gets treated as a remote-fs rather than local-fs
  * Mount2
  - Updated go-fuse version
  - Fixed statfs
  - Disable xattrs
  * VFS
  - Add MkdirAll function to make a directory and all beneath
  - Fix reload: failed to add virtual dir entry: file does not exist
  - Fix writing to a read only directory creating spurious directory entries
  - Fix potential data race
  - Fix backends being Shutdown too early when startup takes a long time
  * Local
  - Fix filtering of symlinks with `-l`/`--links` flag
  - Fix /path/to/file.rclonelink when `-l`/`--links` is in use
  - Fix crash with `--metadata` on Android
  * Cache
  - Fix backends shutting down when in use when used via the rc
  * Crypt
  - Add `--crypt-suffix` option to set a custom suffix for encrypted files
  - Add `--crypt-pass-bad-blocks` to allow corrupted file output
  - Fix reading 0 length files
  - Try not to return "unexpected EOF" error
  - Reduce allocations
  - Recommend Dropbox for `base32768` encoding
  * Azure Blob
  - Empty directory markers
  - Support azure workload identities
  - Fix azure blob uploads with multiple bits of metadata
  - Fix azurite compatibility by sending nil tier if set to empty string
  * Combine
  - Implement missing methods
  - Fix goroutine stack overflow on bad object
  * Drive
  - Add `--drive-env-auth` to get IAM credentials from runtime
  - Update drive service account guide
  - Fix change notify picking up files outside the root
  - Fix trailing slash mis-identificaton of folder as file
  - Fix incorrect remote after Update on object
  * Dropbox
  - Implement `--dropbox-pacer-min-sleep` flag
  - Fix the dropbox batcher stalling
  * Fichier
  - Add `--ficicher-cdn` option to use the CDN for download
  * FTP
  - Lower log message priority when `SetModTime` is not supported to debug
  - Fix "unsupported LIST line" errors on startup
  - Fix "501 Not a valid pathname." errors when creating directories
  * Google Cloud Storage
  - Empty directory markers
  - Added `--gcs-user-project` needed for requester pays
  * HTTP
  - Add client certificate user auth middleware. This can auth `serve restic` from the username
    in the client cert.
  * Jottacloud
  - Fix vfs writeback stuck in a failed upload loop with file versioning disabled
  * Onedrive
  - Add `--onedrive-av-override` flag to download files flagged as virus
  - Fix quickxorhash on 32 bit architectures
  - Report any list errors during `rclone cleanup`
  * Putio
  - Fix uploading to the wrong object on Update with overriden remote name
  - Fix modification times not being preserved for server side copy and move
  - Fix server side copy failures (400 errors)
  * S3
  - Empty directory markers
  - Update Scaleway storage classes
  - Fix `--s3-versions` on individual objects
  - Fix hang on aborting multpart upload with iDrive e2
  - Fix missing "tier" metadata
  - Fix V3sign: add missing subresource delete
  - Fix Arvancloud Domain and region changes and alphabetise the provider
  - Fix Qiniu KODO quirks virtualHostStyle is false
  * SFTP
  - Add `--sftp-host-key-algorithms ` to allow specifying SSH host key algorithms
  - Fix using `--sftp-key-use-agent` and `--sftp-key-file` together needing private key file
  - Fix move to allow overwriting existing files
  - Don't stat directories before listing them
  - Don't check remote points to a file if it ends with /
  * Sharefile
  - Disable streamed transfers as they no longer work
  * Smb
  - Code cleanup to avoid overwriting ctx before first use (fixes issue reported by
    the staticcheck linter)
  * Storj
  - Fix "uplink: too many requests" errors when uploading to the same file
  - Fix uploading to the wrong object on Update with overriden remote name
  * Swift
  - Ignore 404 error when deleting an object
  * Union
  - Implement missing methods
  - Allow errors to be unwrapped for inspection
  * Uptobox
  - Add `--uptobox-private` flag to make all uploaded files private
  - Fix improper regex
  - Fix Update returning the wrong object
  - Fix rmdir declaring that directories weren't empty
  * WebDAV
  - nextcloud: Add support for chunked uploads
  - Set modtime using propset for owncloud and nextcloud
  - Make pacer minSleep configurable with `--webdav-pacer-min-sleep`
  - Fix server side copy/move not overwriting
  - Fix modtime on server side copy for owncloud and nextcloud
  * Yandex
  - Fix 400 Bad Request on transfer failure
  * Zoho
  - Fix downloads with `Range:` header returning the wrong data
* Sun Apr  2 2023 Carsten Ziepke <kieltux@gmail.com>
- Use gcc11 for openSUSE Leap 15.5, fix building
* Tue Mar 21 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.62.2:
  * New features:
  - accounting: Make checkers show what they are doing
  - authorize: Add support for custom templates
  - Update to go1.20
  - filter: Emit INFO message when can't work out directory filters
  - fs
    + Added multiple ca certificate support.
    + Add --max-delete-size a delete size threshold
  - fspath: Allow the symbols @ and + in remote names
  - lib/terminal: Enable windows console virtual terminal sequences processing
  - move: If --check-first and --order-by are set then delete with perfect ordering
  - serve http: Support --auth-proxy
  * Bug fixes:
  - accounting
    + Avoid negative ETA values for very slow speedsy
    + Limit length of ETA string
    + Show human readable elapsed time when longer than a day
  - deletefile: Return error code 4 if file does not exist
  - docker: Fix volume plugin does not remount volume on docker restart
  - fs: Fix race conditions in --max-delete and --max-delete-size
  - lib/oauthutil: Handle fatal errors better
  - mount2: Fix --allow-non-empty
  - operations: Fix concurrency: use --checkers unless transferring files
  - serve ftp: Fix timestamps older than 1 year in listings
  - sync: Fix concurrency: use --checkers unless transferring files
  - Mount
    + Fix creating and renaming files on case insensitive backends (Nick Craig-Wood)
    + Do not treat \\?\ prefixed paths as network share paths on windows (albertony)
    + Fix check for empty mount point on Linux (Nick Craig-Wood)
    + Fix --allow-non-empty (Nick Craig-Wood)
    + Avoid incorrect or premature overlap check on windows (albertony)
    + Update to fuse3 after bazil.org/fuse update (Nick Craig-Wood)
  - VFS
    + Make uploaded files retain modtime with non-modtime backends (Nick Craig-Wood)
    + Fix incorrect modtime on fs which don't support setting modtime (Nick Craig-Wood)
    + Fix rename of directory containing files to be uploaded (Nick Craig-Wood)
  - Local
    + Fix %%!w(<nil>) in "failed to read directory" error (Marks Polakovs)
    + Fix exclusion of dangling symlinks with -L/--copy-links (Nick Craig-Wood)
  - Crypt
    + Obey --ignore-checksum (Nick Craig-Wood)
    + Fix for unencrypted directory names on case insensitive remotes (Ole Frost)
  - Azure Blob
    + Remove workarounds for SDK bugs after v0.6.1 update (Nick Craig-Wood)
  - B2
    + Fix uploading files bigger than 1TiB (Nick Craig-Wood)
  - Drive
    + Note that --drive-acknowledge-abuse needs SA Manager permission (Nick Craig-Wood)
    + Make --drive-stop-on-upload-limit to respond to storageQuotaExceeded (Ninh Pham)
  - FTP
    + Retry 426 errors (Nick Craig-Wood)
    + Retry errors when initiating downloads (Nick Craig-Wood)
    + Revert to upstream github.com/jlaffaye/ftp now fix is merged (Nick Craig-Wood)
    + Google Cloud Storage
    + Add --gcs-env-auth to pick up IAM credentials from env/instance (Peter Brunner)
  - Mega
    + Add --mega-use-https flag (NodudeWasTaken)
  - Onedrive
    + Default onedrive personal to QuickXorHash as Microsoft is removing SHA1 (Nick Craig-Wood)
    + Add --onedrive-hash-type to change the hash in use (Nick Craig-Wood)
    + Improve speed of QuickXorHash (LXY)
    + Oracle Object Storage
    + Speed up operations by using S3 pacer and setting minsleep to 10ms (Manoj Ghosh)
    + Expose the storage_tier option in config (Manoj Ghosh)
    + Bring your own encryption keys (Manoj Ghosh)
  - S3
    + Check multipart upload ETag when --s3-no-head is in use (Nick Craig-Wood)
    + Add --s3-sts-endpoint to specify STS endpoint (Nick Craig-Wood)
    + Fix incorrect tier support for StorJ and IDrive when pointing at a file (Ole Frost)
    + Fix AWS STS failing if --s3-endpoint is set (Nick Craig-Wood)
    + Make purge remove directory markers too (Nick Craig-Wood)
  - Seafile
    + Renew library password (Fred)
  - SFTP
    + Fix uploads being 65%% slower than they should be with crypt (Nick Craig-Wood)
  - Smb
    + Allow SPN (service principal name) to be configured (Nick Craig-Wood)
    + Check smb connection is closed (happyxhw)
  - Storj
    + Implement rclone link (Kaloyan Raev)
    + Implement rclone purge (Kaloyan Raev)
    + Update satellite urls and labels (Kaloyan Raev)
  - WebDAV
    + Fix interop with davrods server (Nick Craig-Wood)
* Mon Jan  2 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.61.1:
  * Bug fixes:
  - lib/http: Shutdown all servers on exit to remove unix socket
  - rc: Fix --rc-addr flag (which is an alternate for --url)
  - serve restic:
    + Don't serve via http if serving via --stdio
    + Fix immediate exit when not using stdio
  - serve webdav:
    + Fix --baseurl handling after lib/http refactor
    + Fix running duplicate Serve call
  * Azure: Fix "409 Public access is not permitted on this storage account"
  * S3: storj: Update endpoints
* Wed Dec 21 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.61.0:
  * Add vulnerability testing using govulncheck
  * dedupe: Count Checks in the stats while scanning for duplicates
  * dedupe: Make dedupe obey the filters
  * filter: Add metadata filters --metadata-include/exclude/filter and friends
  * fs: Make all duration flags take y, M, w, d etc suffixes
  * fs: Add global flag --color to control terminal colors
  * fspath: Allow unicode numbers and letters in remote names
  * ncdu: Add support for modification time
  * ncdu: Fallback to sort by name also for sort by average size
  * ncdu: Rework to use tcell directly instead of the termbox wrapper
  * rc: Add commands to set GC Percent & Memory Limit
  * rcat: Preserve metadata when Copy falls back to Rcat
  * rcd: Refactor rclone rc server to use lib/http
  * rcserver: Avoid generating default credentials with htpasswd
  * vfs: Fix IO Error opening a file with O_CREATE|O_RDONLY in --vfs-cache-mode not full
  * crypt: Fix compress wrapping crypt giving upload errors
  * Azure:
  - Port to new SDK
  - Add --azureblob-no-check-container to assume container exists
  - Add --use-server-modtime support
  - Add support for custom upload headers
  - Allow emulator account/key override
  - Support simple "environment credentials"
  - Ignore AuthorizationFailure when trying to create a create a container
  * Drive: Handle shared drives with leading/trailing space in name
  * Onedrive: Document workaround for shared with me files
  * S3:
  - Add Liara LOS to provider list
  - Add DigitalOcean Spaces regions sfo3, fra1, syd1
  - Avoid privileged GetBucketLocation to resolve s3 region
  - Stop setting object and bucket ACL to private if it is an empty string
  - If bucket or object ACL is empty string then don't add X-Amz-Acl: header
  - Reduce memory consumption for s3 objects
  - Fix listing loop when using v2 listing on v1 server
  - Fix nil pointer exception when using Versions
  - Fix excess memory usage when using versions
  - Ignore versionIDs from uploads unless using --s3-versions or --s3-versions-at
  * SFTP:
  - Add configuration options to set ssh Ciphers / MACs / KeyExchange
  - Auto-detect shell type for fish
  - Fix NewObject with leading /
* Tue Nov 22 2022 pousaduarte@gmail.com
- Update to version 1.60.1:
  * Version v1.60.1
  * docs: faq: how to use a proxy server that requires a username and password - fixes #6565
  * webdav: fix Move/Copy/DirMove when using -server-side-across-configs
  * smb: fix Failed to sync: context canceled at the end of syncs
  * vfs: fix deadlock caused by cache cleaner and upload finishing
  * s3: Add additional Wasabi locations
  * s3: fix for unchecked err value in s3 listv2
  * local: fix -L/--copy-links with filters missing directories
  * mailru: allow timestamps to be before the epoch 1970-01-01
  * lib/cache: fix alias backend shutting down too soon
* Mon May  2 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.58.1:
  * webdav: Don't override Referer if user sets it
  * sftp: Fix OpenSSH 8.8+ RSA keys incompatibility
  * s3: Add ChinaMobile EOS to provider list
  * s3: Sync providers in config description with providers
  * onedrive: Note that sharepoint also changes web files (.html, .aspx)
  * jottacloud: Fix scope in token request
  * GCS: Use the s3 pacer to speed up transactions
  * GCS: pacer: Default the Google pacer to a burst of 100 to fix gcs pacing
  * dropbox: Fix retries of multipart uploads with incorrect_offset error
  * VFS: Remove wording which suggests VFS is only for mounting
  * mount: Fix --devname and fusermount: unknown option 'fsname' when mounting via rc
  * Fix timezone of --min-age/-max-age from UTC to local as documented
  * rc/js: Correct RC method names
* Sat Mar 19 2022 Fusion Future <qydwhotmail@gmail.com>
- Update to 1.58.0
  * See https://rclone.org/changelog/#v1-58-0-2022-03-18 for their
    complete changelog.
  * New backends: Akamai Netstorage, Seagate Lyve, SeaweedFS, Storj,
    RackCorp, Storj (renamed from Tardigrade)
  * New commands: bisync - experimental bidirectional cloud sync
  * tree: Remove obsolete --human replaced by global --human-readable
* Sat Feb  5 2022 Marcus Rueckert <mrueckert@suse.de>
- Fix warning about packageand() by replacing the package and with
  (rclone and $other_package_name) syntax
- add BR for golang-packaging to get the %%{go_nostrip} macro
* Sun Nov  7 2021 Fusion Future <qydwhotmail@gmail.com>
- Update to 1.57.0
  * See https://rclone.org/changelog/#v1-57-0-2021-11-01 for the
    complete changelog.
  * Major new features
  - Use go1.17 for building and make go1.14 the minimum supported.
  - fs: Move with --ignore-existing will not delete skipped files.
  - touch: Add support for touching files in directory, with
    recursive option, filtering and --dry-run/-i.
* Wed Sep  1 2021 Fusion Future <qydwhotmail@gmail.com>
- Update to 1.56.1
  * See https://rclone.org/changelog/#v1-56-1-2021-09-19 for the
    complete changelog.
  * accounting: Fix maximum bwlimit by scaling scale max token bucket
    size
  * rc: Fix speed does not update in core/stats
  * selfupdate: Fix --quiet option, not quite quiet
  * serve http: Fix serve http exiting directly after starting
  * Apply gofmt from golang 1.17
  * Update Go to 1.16 and NDK to 22b for android/any
- Changes in 1.56.0
  * See https://rclone.org/changelog/#v1-56-0-2021-07-20 for the
    complete changelog.
* Wed May 19 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.55.1
  * VFS: Fix a code path which allows dirty data to be removed
    causing data loss
  * Compress: Fix compressed name regexp
  * Drive: Fix backend copyid of google doc to directory
  * Don't open browser when service account
  * Dropbox: Add missing team_data.member scope for use
    with --impersonate
  * Fix About after scopes changes - rclone config reconnect
    needed
  * Fix Unable to decrypt returned paths from changeNotify
  * FTP: Fix implicit TLS
  * Onedrive: Work around for random "Unable to initialize RPS" errors
  * SFTP: Fix Update ReadFrom failed: failed to send packet: EOF errors
  * Zoho: Fix error when region isn't set
  * Do not ask for mountpoint twice when using headless setup
* Thu Apr  1 2021 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.55.0
  * See https://rclone.org/changelog/#v1-55-0-2021-03-31 for the
    complete changelog.
* Mon Mar  8 2021 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.54.1
  * Bug Fixes
  - accounting: Fix --bwlimit when up or down is off (Nick Craig-Wood)
  - docs
    + Fix nesting of brackets and backticks in ftp docs (edwardxml)
    + Fix broken link in sftp page (edwardxml)
    + Fix typo in crypt.md (Romeo Kienzler)
    + Changelog: Correct link to digitalis.io (Alex JOST)
    + Replace #file-caching with #vfs-file-caching (Miron Veryanskiy)
    + Convert bogus example link to code (edwardxml)
    + Remove dead link from rc.md (edwardxml)
  - rc: Sync,copy,move: document createEmptySrcDirs parameter (Nick Craig-Wood)
  - lsjson: Fix unterminated JSON in the presence of errors (Nick Craig-Wood)
  * Mount
  - Fix mount dropping on macOS by setting --daemon-timeout 10m (Nick Craig-Wood)
  * VFS
  - Document simultaneous usage with the same cache shouldn't be used (Nick Craig-Wood)
  * B2
  - Automatically raise upload cutoff to avoid spurious error (Nick Craig-Wood)
  - Fix failed to create file system with application key limited to a prefix (Nick Craig-Wood)
  * Drive
  - Refer to Shared Drives instead of Team Drives (Nick Craig-Wood)
  * Dropbox
  - Add scopes to oauth request and optionally "members.read" (Nick Craig-Wood)
  * S3
  - Fix failed to create file system with folder level permissions policy (Nick Craig-Wood)
  - Fix Wasabi HEAD requests returning stale data by using only 1 transport (Nick Craig-Wood)
  - Fix shared_credentials_file auth (Dmitry Chepurovskiy)
  - Add --s3-no-head to reducing costs docs (Nick Craig-Wood)
  * Union
  - Fix mkdir at root with remote:/ (Nick Craig-Wood)
  * Zoho
  - Fix custom client id's (buengese)
* Thu Feb  4 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.54.0:
  * New backends
  - Compression remote (experimental)
  - Enterprise File Fabric
  - HDFS (Hadoop Distributed File System
  - Zoho workdrive
  * New Features
  - Deglobalise the config
  - Add --bwlimit for upload and download
  - Enhance systemd integration
  - Add a --download flag to md5sum/sha1sum/hashsum to force rclone
    to download and hash files locally
  - Add --progress-terminal-title to print ETA to terminal title
  - Make backend env vars show in help as the defaults for backend flags
  - dedupe: add '--by-hash' and '--dedupe-mode list'
  - obscure: Make rclone osbcure - ignore newline at end of line
  - serve ftp: Add options to enable TLS
  - serve http/webdav: Redirect requests to the base url without the /
  - serve restic: Implement object cache
  - stats: Add counter for deleted directories
  - sync: Only print "There was nothing to transfer" if no errors
  * Bug fixes
  - log: Fix enabling systemd logging when using --log-fil
  - move: Fix data loss when source and destination are the same object
  - operations: Fix --cutof-mode and --immutable
  * Docs update
  * Mount fixes
  * VFS fixes
  * Local fixes
  * Azure
  - Add support for service principals
  - Add support for managed identities
  - Utilize the streaming capabilities from the SDK for multipart uploads
  - Fix setting of mime types
  - Fix crash when listing outside a SAS URL's root
  - Require go1.14+ to compile due to SDK changes
  * B2
  - Make NewObject use less expensive API calls
  - Fixed crash on an empty file name
  * Box
  - Fix NewObject for files that differ in case
  - Fix finding directories in a case insentive way
  * Drive
  - Implement rclone backend copyid command for copying files by ID
  - Added flag --drive-stop-on-download-limit to stop transfers
    when the download limit is exceeded
  - Implement CleanUp workaround for team drives
  - Allow shortcut resolution and creation to be retried
  - Log that emptying the trash can take some time
  * Dropbox
  - Add support for viewing shared files and folders
  - Enable short lived access tokens
  - Implement IDer on Objects so rclone lsf etc can read the IDs
  - Set Features ReadMimeType to false as Object.MimeType not supported
  - Make malformed_path errors from too long files not retriable
  * S3
  - Added --s3-disable-http2 to disable http/2
  - Complete SSE-C implementation
  - Add --s3-no-head parameter to minimise transactions on upload
  - Add requester pays option
  - Fix copy multipart with v2 auth failing with 'SignatureDoesNotMatch'
  * SFTP
  - Allow cert based auth via optional pubkey
  - Allow user to optionally check server hosts key to add security
  - Defer asking for user passwords until the SSH connection succeeds
  - Remember entered password in AskPass mode
  - Implement Shutdown method
  - Make --tpslimit apply
  - Implement --sftp-use-fstat for unusual SFTP servers
  * Various fixes to other providers
* Thu Jan 21 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.53.4:
  * Bug Fixes
  - accounting: Fix data race in Transferred()
  - build
    + Stop tagged releases making a current beta
  - fs: Parseduration: fixed tests to use UTC time
  - fshttp: Prevent overlap of HTTP headers in logs
  - rc
    + Fix core/command giving 500 internal error
    + Add Copy method to rc.Params
    + Fix 500 error when marshalling errors from core/command
    + plugins: Create plugins files only if webui is enabled.
  - serve http: Fix serving files of unknown length
  - serve sftp: Fix authentication on one connection blocking others
  * Mount
  - Add "." and ".." to directories to match cmount and expectations
  * VFS
  - Make cache dir absolute before using it to fix path too long errors
  * Chunker
  - Improve detection of incompatible metadata
  * Google Cloud Storage
  - Fix server side copy of large objects
  * Jottacloud
  - Fix token renewer to fix long uploads
  - Fix token refresh failed: is not a regular file error
  * Pcloud
  - Only use SHA1 hashes in EU region
  * Sharefile
  - Undo Fix backend due to API swapping integers for strings
  * WebDAV
  - Fix Open Range requests to fix 4shared mount
  - Add "Depth: 0" to GET requests to fix bitrix
* Fri Nov 20 2020 İsmail Dönmez <idoenmez+factory@suse.de>
- Update to version 1.53.3
  * Bug Fixes
  - Fix incorrect use of math/rand instead of crypto/rand
    CVE-2020-28924 boo#1179005 (Nick Craig-Wood)
  - Check https://github.com/rclone/passwordcheck for a tool check for
    weak passwords generated by rclone
  * VFS
  - Fix vfs/refresh calls with fs= parameter (Nick Craig-Wood)
  * Sharefile
  - Fix backend due to API swapping integers for strings (Nick Craig-Wood)
* Tue Oct 27 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.53.2:
  * Bug Fixes
  - accounting
    + Fix incorrect speed and transferTime in core/stats (Nick Craig-Wood)
    + Stabilize display order of transfers on Windows (Nick Craig-Wood)
  - operations
    + Fix use of --suffix without --backup-dir (Nick Craig-Wood)
    + Fix spurious "--checksum is in use but the source and destination have no hashes in common" (Nick Craig-Wood)
  - build
    + Work around GitHub actions brew problem (Nick Craig-Wood)
    + Stop using set-env and set-path in the GitHub actions (Nick Craig-Wood)
  * Mount
  - mount2: Fix the swapped UID / GID values (Russell Cattelan)
  * VFS
  - Detect and recover from a file being removed externally from the cache (Nick Craig-Wood)
  - Fix a deadlock vulnerability in downloaders.Close (Leo Luan)
  - Fix a race condition in retryFailedResets (Leo Luan)
  - Fix missed concurrency control between some item operations and reset (Leo Luan)
  - Add exponential backoff during ENOSPC retries (Leo Luan)
  - Add a missed update of used cache space (Leo Luan)
  - Fix --no-modtime to not attempt to set modtimes (as documented) (Nick Craig-Wood)
  * Local
  - Fix sizes and syncing with --links option on Windows (Nick Craig-Wood)
  * Chunker
  - Disable ListR to fix missing files on GDrive (workaround) (Ivan Andreev)
  - Fix upload over crypt (Ivan Andreev)
  * Fichier
  - Increase maximum file size from 100GB to 300GB (gyutw)
  * Jottacloud
  - Remove clientSecret from config when upgrading to token based authentication (buengese)
  - Avoid double url escaping of device/mountpoint (albertony)
  - Remove DirMove workaround as it's not required anymore - also (buengese)
  * Mailru
  - Fix uploads after recent changes on server (Ivan Andreev)
  - Fix range requests after june changes on server (Ivan Andreev)
  - Fix invalid timestamp on corrupted files (fixes) (Ivan Andreev)
  * Onedrive
  - Fix disk usage for sharepoint (Nick Craig-Wood)
  * S3
  - Add missing regions for AWS (Anagh Kumar Baranwal)
  * Seafile
  - Fix accessing libraries > 2GB on 32 bit systems (Muffin King)
  * SFTP
  - Always convert the checksum to lower case (buengese)
  * Union
  - Create root directories if none exist (Nick Craig-Wood)
* Thu Sep 17 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to version 1.53.1:
  * Bug Fixes
  - accounting: Remove new line from end of --stats-one-line display
  * VFS
  - Fix spurious error "vfs cache: failed to _ensure cache EOF"
  - Log an ERROR if we fail to set the file to be sparse
  * Local
  - Log an ERROR if we fail to set the file to be sparse
  * Drive
  - Re-adds special oauth help text
  * Opendrive
  - Do not retry 400 errors
* Fri Sep  4 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to version 1.53.0
  * New Features
  - The VFS layer was heavily reworked for this release - see below for more details
  - Interactive mode -i/--interactive for destructive operations (fishbullet)
  - Add --bwlimit-file flag to limit speeds of individual file transfers (Nick Craig-Wood)
  - Transfers are sorted by start time in the stats and progress output (Max Sum)
  - Make sure backends expand ~ and environment vars in file names they use (Nick Craig-Wood)
  - Add --refresh-times flag to set modtimes on hashless backends (Nick Craig-Wood)
  - rclone check
    + Add reporting of filenames for same/missing/changed (Nick Craig-Wood)
    + Make check command obey --dry-run/-i/--interactive (Nick Craig-Wood)
    + Make check do --checkers files concurrently (Nick Craig-Wood)
    + Retry downloads if they fail when using the --download flag (Nick Craig-Wood)
    + Make it show stats by default (Nick Craig-Wood)
  - rclone config
    + Set RCLONE_CONFIG_DIR for use in config files and subprocesses (Nick Craig-Wood)
    + Reject remote names starting with a dash. (jtagcat)
  - rclone cryptcheck: Add reporting of filenames for same/missing/changed (Nick Craig-Wood)
  - rclone dedupe: Make it obey the --size-only flag for duplicate detection (Nick Craig-Wood)
  - rclone link: Add --expire and --unlink flags (Roman Kredentser)
  - rclone mkdir: Warn when using mkdir on remotes which can't have empty directories (Nick Craig-Wood)
  - rclone rc: Allow JSON parameters to simplify command line usage (Nick Craig-Wood)
  - rclone serve ftp
    + Don't compile on < go1.13 after dependency update (Nick Craig-Wood)
    + Add error message if auth proxy fails (Nick Craig-Wood)
    + Use refactored goftp.io/server library for binary shrink (Nick Craig-Wood)
  - rclone serve restic: Expose interfaces so that rclone can be used as a library from within restic (Jack)
  - rclone sync: Add --track-renames-strategy leaf (Nick Craig-Wood)
  - rclone touch: Add ability to set nanosecond resolution times (Nick Craig-Wood)
  - rclone tree: Remove -i shorthand for --noindent as it conflicts with -i/--interactive (Nick Craig-Wood)
  * Bug Fixes
  * Mount
  - rc interface
    + Add call for unmount all (Chaitanya Bankanhal)
    + Make mount/mount remote control take vfsOpt option (Nick Craig-Wood)
    + Add mountOpt to mount/mount (Nick Craig-Wood)
    + Add VFS and Mount options to mount/listmounts (Nick Craig-Wood)
  - Catch panics in cgofuse initialization and turn into error messages (Nick Craig-Wood)
  - Always supply stat information in Readdir (Nick Craig-Wood)
  - Add support for reading unknown length files using direct IO (Windows) (Nick Craig-Wood)
  - Fix On Windows don't add -o uid/gid=-1 if user supplies -o uid/gid. (Nick Craig-Wood)
  - Fix volume name broken in recent refactor (Nick Craig-Wood)
  * VFS
  - Implement partial reads for --vfs-cache-mode full (Nick Craig-Wood)
  - Add --vfs-writeback option to delay writes back to cloud storage (Nick Craig-Wood)
  - Add --vfs-read-ahead parameter for use with --vfs-cache-mode full (Nick Craig-Wood)
  - Restart pending uploads on restart of the cache (Nick Craig-Wood)
  - Support synchronous cache space recovery upon ENOSPC (Leo Luan)
  - Allow ReadAt and WriteAt to run concurrently with themselves (Nick Craig-Wood)
  - Change modtime of file before upload to current (Rob Calistri)
  - Recommend --vfs-cache-modes writes on backends which can't stream (Nick Craig-Wood)
  - Add an optional fs parameter to vfs rc methods (Nick Craig-Wood)
  - Fix errors when using > 260 char files in the cache in Windows (Nick Craig-Wood)
  - Fix renaming of items while they are being uploaded (Nick Craig-Wood)
  - Fix very high load caused by slow directory listings (Nick Craig-Wood)
  - Fix renamed files not being uploaded with --vfs-cache-mode minimal (Nick Craig-Wood)
  - Fix directory locking caused by slow directory listings (Nick Craig-Wood)
  - Fix saving from chrome without --vfs-cache-mode writes (Nick Craig-Wood)
  * Crypt
    Add --crypt-server-side-across-configs flag (Nick Craig-Wood)
    Make any created backends be cached to fix rc problems (Nick Craig-Wood)
  * Azure Blob
    Don't compile on < go1.13 after dependency update (Nick Craig-Wood)
  * B2
    Implement server side copy for files > 5GB (Nick Craig-Wood)
    Cancel in progress multipart uploads and copies on rclone exit (Nick Craig-Wood)
    Note that b2's encoding now allows \ but rclone's hasn't changed (Nick Craig-Wood)
    Fix transfers when using download_url (Nick Craig-Wood)
  * Box
  - Implement rclone cleanup (buengese)
  - Cancel in progress multipart uploads and copies on rclone exit (Nick Craig-Wood)
  - Allow authentication with access token (David)
  * Chunker
  - Make any created backends be cached to fix rc problems (Nick Craig-Wood)
  * Drive
  - Add rclone backend drives to list shared drives (teamdrives) (Nick Craig-Wood)
  - Implement rclone backend untrash (Nick Craig-Wood)
  - Work around drive bug which didn't set modtime of copied docs (Nick Craig-Wood)
  - Added --drive-starred-only to only show starred files (Jay McEntire)
  - Deprecate --drive-alternate-export as it is no longer needed (themylogin)
  - Fix duplication of Google docs on server side copy (Nick Craig-Wood)
  - Fix "panic: send on closed channel" when recycling dir entries (Nick Craig-Wood)
  * Dropbox
  - Add copyright detector info in limitations section in the docs (Alex Guerrero)
  - Fix rclone link by removing expires parameter (Nick Craig-Wood)
  * Fichier
  - Detect Flood detected: IP Locked error and sleep for 30s (Nick Craig-Wood)
  * FTP
  - Add explicit TLS support (Heiko Bornholdt)
  - Add support for --dump bodies and --dump auth for debugging (Nick Craig-Wood)
  - Fix interoperation with pure-ftpd (Nick Craig-Wood)
  * Google Cloud Storage
  - Add support for anonymous access (Kai Lüke)
  * Jottacloud
  - Bring back legacy authentification for use with whitelabel versions (buengese)
  - Switch to new api root - also implement a very ugly workaround for the DirMove failures (buengese)
  * Onedrive
  - Rework cancel of multipart uploads on rclone exit (Nick Craig-Wood)
  - Implement rclone cleanup (Nick Craig-Wood)
  - Add --onedrive-no-versions flag to remove old versions (Nick Craig-Wood)
  * Pcloud
  - Implement rclone link for public link creation (buengese)
  * Qingstor
  - Cancel in progress multipart uploads on rclone exit (Nick Craig-Wood)
  * S3
  - Preserve metadata when doing multipart copy (Nick Craig-Wood)
  - Cancel in progress multipart uploads and copies on rclone exit (Nick Craig-Wood)
  - Add rclone link for public link sharing (Roman Kredentser)
  - Add rclone backend restore command to restore objects from GLACIER (Nick Craig-Wood)
  - Add rclone cleanup and rclone backend cleanup to clean unfinished multipart uploads (Nick Craig-Wood)
  - Add rclone backend list-multipart-uploads to list unfinished multipart uploads (Nick Craig-Wood)
  - Add --s3-max-upload-parts support (Kamil Trzciński)
  - Add --s3-no-check-bucket for minimising rclone transactions and perms (Nick Craig-Wood)
  - Add --s3-profile and --s3-shared-credentials-file options (Nick Craig-Wood)
  - Use regional s3 us-east-1 endpoint (David)
  - Add Scaleway provider (Vincent Feltz)
  - Update IBM COS endpoints (Egor Margineanu)
  - Reduce the default --s3-copy-cutoff to < 5GB for Backblaze S3 compatibility (Nick Craig-Wood)
  - Fix detection of bucket existing (Nick Craig-Wood)
  * SFTP
  - Use the absolute path instead of the relative path for listing for improved compatibility (Nick Craig-Wood)
  - Add --sftp-subsystem and --sftp-server-command options (aus)
  * Swift
  - Fix dangling large objects breaking the listing (Nick Craig-Wood)
  - Fix purge not deleting directory markers (Nick Craig-Wood)
  - Fix update multipart object removing all of its own parts (Nick Craig-Wood)
  - Fix missing hash from object returned from upload (Nick Craig-Wood)
  * Tardigrade
  - Upgrade to uplink v1.2.0 (Kaloyan Raev)
  * Union
  - Fix writing with the all policy (Nick Craig-Wood)
  * WebDAV
  - Fix directory creation with 4shared (Nick Craig-Wood)
* Sat Aug  8 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.52.3
  * Bug Fixes
  - docs
    + Disable smart typography (eg en-dash) in MANUAL.* and man page (Nick Craig-Wood)
    + Update install.md to reflect minimum Go version (Evan Harris)
    + Update install from source instructions (Nick Craig-Wood)
    + make_manual: Support SOURCE_DATE_EPOCH (Morten Linderud)
  - log: Fix --use-json-log going to stderr not --log-file on Windows (Nick Craig-Wood)
  - serve dlna: Fix file list on Samsung Series 6+ TVs (Matteo Pietro Dazzi)
  - sync: Fix deadlock with --track-renames-strategy modtime (Nick Craig-Wood)
  * Cache
  - Fix moveto/copyto remote:file remote:file2 (Nick Craig-Wood)
  * Drive
  - Stop using root_folder_id as a cache (Nick Craig-Wood)
  - Make dangling shortcuts appear in listings (Nick Craig-Wood)
  - Drop "Disabling ListR" messages down to debug (Nick Craig-Wood)
  - Workaround and policy for Google Drive API (Dmitry Ustalov)
  * FTP
  - Add note to docs about home vs root directory selection (Nick Craig-Wood)
  * Onedrive
  - Fix reverting to Copy when Move would have worked (Nick Craig-Wood)
  - Avoid comma rendered in URL in onedrive.md (Kevin)
  * Pcloud
  - Fix oauth on European region "eapi.pcloud.com" (Nick Craig-Wood)
  * S3
  - Fix bucket Region auto detection when Region unset in config (Nick Craig-Wood)
* Wed Jun 24 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.52.2
  * Bug Fixes
  - build
    + Fix docker release build action (Nick Craig-Wood)
    + Fix custom timezone in Docker image (NoLooseEnds)
  - check: Fix misleading message which printed errors instead of differences (Nick Craig-Wood)
  - errors: Add WSAECONNREFUSED and more to the list of retriable Windows errors (Nick Craig-Wood)
  - rcd: Fix incorrect prometheus metrics (Gary Kim)
  - serve restic: Fix flags so they use environment variables (Nick Craig-Wood)
  - serve webdav: Fix flags so they use environment variables (Nick Craig-Wood)
  - sync: Fix --track-renames-strategy modtime (Nick Craig-Wood)
  * Drive
  - Fix not being able to delete a directory with a trashed shortcut (Nick Craig-Wood)
  - Fix creating a directory inside a shortcut (Nick Craig-Wood)
  - Fix --drive-impersonate with cached root_folder_id (Nick Craig-Wood)
  * SFTP
  - Fix SSH key PEM loading (Zac Rubin)
  * Swift
  - Speed up deletes by not retrying segment container deletes (Nick Craig-Wood)
  * Tardigrade
  - Upgrade to uplink v1.1.1 (Caleb Case)
  * WebDAV
  - Fix free/used display for rclone about/df for certain backends (Nick Craig-Wood)
* Wed Jun 10 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.52.1
  * VFS
  - Fix OS vs Unix path confusion - fixes ChangeNotify on Windows (Nick Craig-Wood)
  * Drive
  - Fix missing items when listing using --fast-list / ListR (Nick Craig-Wood)
  * Putio
  - Fix panic on Object.Open (Cenk Alti)
  * S3
  - Fix upload of single files into buckets without create permission (Nick Craig-Wood)
  - Fix --header-upload (Nick Craig-Wood)
  * Tardigrade
  - Fix listing bug by upgrading to v1.0.7
  - Set UserAgent to rclone (Caleb Case)
* Thu May 28 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.52.0
  * New backends
  - Tardigrade backend for use with storj.io (Caleb Case)
  - Union re-write to have multiple writable remotes (Max Sum)
  - Seafile for Seafile server (Fred @creativeprojects)
  * New commands
  - backend: command for backend specific commands (see backends) (Nick Craig-Wood)
  - cachestats: Deprecate in favour of rclone backend stats cache: (Nick Craig-Wood)
  - dbhashsum: Deprecate in favour of rclone hashsum DropboxHash (Nick Craig-Wood)
  * New Features
  - Add --header-download and --header-upload flags for setting HTTP headers when uploading/downloading (Tim Gallant)
  - Add --header flag to add HTTP headers to every HTTP transaction (Nick Craig-Wood)
  - Add --check-first to do all checking before starting transfers (Nick Craig-Wood)
  - Add --track-renames-strategy for configurable matching criteria for --track-renames (Bernd Schoolmann)
  - Add --cutoff-mode hard,soft,catious (Shing Kit Chan & Franklyn Tackitt)
  - Filter flags (eg --files-from -) can read from stdin (fishbullet)
  - Add --error-on-no-transfer option (Jon Fautley)
  - Implement --order-by xxx,mixed for copying some small and some big files (Nick Craig-Wood)
  - Allow --max-backlog to be negative meaning as large as possible (Nick Craig-Wood)
  - Added --no-unicode-normalization flag to allow Unicode filenames to remain unique (Ben Zenker)
  - Allow --min-age/--max-age to take a date as well as a duration (Nick Craig-Wood)
  - Add rename statistics for file and directory renames (Nick Craig-Wood)
  - Add statistics output to JSON log (reddi)
  - Make stats be printed on non-zero exit code (Nick Craig-Wood)
  - When running --password-command allow use of stdin (Sébastien Gross)
  - Stop empty strings being a valid remote path (Nick Craig-Wood)
  - accounting: support WriterTo for less memory copying (Nick Craig-Wood)
  - build
    + Update to use go1.14 for the build (Nick Craig-Wood)
    + Add -trimpath to release build for reproduceable builds (Nick Craig-Wood)
    + Remove GOOS and GOARCH from Dockerfile (Brandon Philips)
  - config
    + Fsync the config file after writing to save more reliably (Nick Craig-Wood)
    + Add --obscure and --no-obscure flags to config create/update (Nick Craig-Wood)
    + Make config show take remote: as well as remote (Nick Craig-Wood)
  - copyurl: Add --no-clobber flag (Denis)
  - delete: Added --rmdirs flag to delete directories as well (Kush)
  - filter: Added --files-from-raw flag (Ankur Gupta)
  - genautocomplete: Add support for fish shell (Matan Rosenberg)
  - log: Add support for syslog LOCAL facilities (Patryk Jakuszew)
  - lsjson: Add --hash-type parameter and use it in lsf to speed up hashing (Nick Craig-Wood)
  - rc
    + Add -o/--opt and -a/--arg for more structured input (Nick Craig-Wood)
    + Implement backend/command for running backend specific commands remotely (Nick Craig-Wood)
    + Add mount/mount command for starting rclone mount via the API (Chaitanya)
  - rcd: Add Prometheus metrics support (Gary Kim)
  - serve http
    + Added a --template flag for user defined markup (calistri)
    + Add Last-Modified headers to files and directories (Nick Craig-Wood)
  - serve sftp: Add support for multiple host keys by repeating --key flag (Maxime Suret)
  - touch: Add --localtime flag to make --timestamp localtime not UTC (Nick Craig-Wood)
  * Bug Fixes
  - accounting
    + Restore "Max number of stats groups reached" log line (Michał Matczuk)
    + Correct exitcode on Transfer Limit Exceeded flag. (Anuar Serdaliyev)
    + Reset bytes read during copy retry (Ankur Gupta)
    + Fix race clearing stats (Nick Craig-Wood)
  - copy: Only create empty directories when they don't exist on the remote (Ishuah Kariuki)
  - dedupe: Stop dedupe deleting files with identical IDs (Nick Craig-Wood)
  - oauth
    + Use custom http client so that --no-check-certificate is honored by oauth token fetch (Mark Spieth)
    + Replace deprecated oauth2.NoContext (Lars Lehtonen)
  - operations
    + Fix setting the timestamp on Windows for multithread copy (Nick Craig-Wood)
    + Make rcat obey --ignore-checksum (Nick Craig-Wood)
    + Make --max-transfer more accurate (Nick Craig-Wood)
  - rc
    + Fix dropped error (Lars Lehtonen)
    + Fix misplaced http server config (Xiaoxing Ye)
    + Disable duplicate log (ElonH)
  - serve dlna
    + Cds: don't specify childCount at all when unknown (Dan Walters)
    + Cds: use modification time as date in dlna metadata (Dan Walters)
  - serve restic: Fix tests after restic project removed vendoring (Nick Craig-Wood)
  - sync
    + Fix incorrect "nothing to transfer" message using --delete-before (Nick Craig-Wood)
    + Only create empty directories when they don't exist on the remote (Ishuah Kariuki)
  * Mount
  - Add --async-read flag to disable asynchronous reads (Nick Craig-Wood)
  - Ignore --allow-root flag with a warning as it has been removed upstream (Nick Craig-Wood)
  - Warn if --allow-non-empty used on Windows and clarify docs (Nick Craig-Wood)
  - Constrain to go1.13 or above otherwise bazil.org/fuse fails to compile (Nick Craig-Wood)
  - Fix fail because of too long volume name (evileye)
  - Report 1PB free for unknown disk sizes (Nick Craig-Wood)
  - Map more rclone errors into file systems errors (Nick Craig-Wood)
  - Fix disappearing cwd problem (Nick Craig-Wood)
  - Use ReaddirPlus on Windows to improve directory listing performance (Nick Craig-Wood)
  - Send a hint as to whether the filesystem is case insensitive or not (Nick Craig-Wood)
  - Add rc command mount/types (Nick Craig-Wood)
  - Change maximum leaf name length to 1024 bytes (Nick Craig-Wood)
  * VFS
  - Add --vfs-read-wait and --vfs-write-wait flags to control time waiting for a sequential read/write (Nick Craig-Wood)
  - Change default --vfs-read-wait to 20ms (it was 5ms and not configurable) (Nick Craig-Wood)
  - Make df output more consistent on a rclone mount. (Yves G)
  - Report 1PB free for unknown disk sizes (Nick Craig-Wood)
  - Fix race condition caused by unlocked reading of Dir.path (Nick Craig-Wood)
  - Make File lock and Dir lock not overlap to avoid deadlock (Nick Craig-Wood)
  - Implement lock ordering between File and Dir to eliminate deadlocks (Nick Craig-Wood)
  - Factor the vfs cache into its own package (Nick Craig-Wood)
  - Pin the Fs in use in the Fs cache (Nick Craig-Wood)
  - Add SetSys() methods to Node to allow caching stuff on a node (Nick Craig-Wood)
  - Ignore file not found errors from Hash in Read.Release (Nick Craig-Wood)
  - Fix hang in read wait code (Nick Craig-Wood)
  * Local
  - Speed up multi thread downloads by using sparse files on Windows (Nick Craig-Wood)
  - Implement --local-no-sparse flag for disabling sparse files (Nick Craig-Wood)
  - Implement rclone backend noop for testing purposes (Nick Craig-Wood)
  - Fix "file not found" errors on post transfer Hash calculation (Nick Craig-Wood)
  * Cache
  - Implement rclone backend stats command (Nick Craig-Wood)
  - Fix Server Side Copy with Temp Upload (Brandon McNama)
  - Remove Unused Functions (Lars Lehtonen)
  - Disable race tests until bbolt is fixed (Nick Craig-Wood)
  - Move methods used for testing into test file (greatroar)
  - Add Pin and Unpin and canonicalised lookup (Nick Craig-Wood)
  - Use proper import path go.etcd.io/bbolt (Robert-André Mauchin)
  * Crypt
  - Calculate hashes for uploads from local disk (Nick Craig-Wood)
    + This allows crypted Jottacloud uploads without using local disk
    + This means crypted s3/b2 uploads will now have hashes
  - Added rclone backend decode/encode commands to replicate functionality of cryptdecode (Anagh Kumar Baranwal)
  - Get rid of the unused Cipher interface as it obfuscated the code (Nick Craig-Wood)
  * Azure Blob
  - Implement streaming of unknown sized files so rcat is now supported (Nick Craig-Wood)
  - Implement memory pooling to control memory use (Nick Craig-Wood)
  - Add --azureblob-disable-checksum flag (Nick Craig-Wood)
  - Retry InvalidBlobOrBlock error as it may indicate block concurrency problems (Nick Craig-Wood)
  - Remove unused Object.parseTimeString() (Lars Lehtonen)
  - Fix permission error on SAS URL limited to container (Nick Craig-Wood)
  * B2
  - Add support for --header-upload and --header-download (Tim Gallant)
  - Ignore directory markers at the root also (Nick Craig-Wood)
  - Force the case of the SHA1 to lowercase (Nick Craig-Wood)
  - Remove unused largeUpload.clearUploadURL() (Lars Lehtonen)
  * Box
  - Add support for --header-upload and --header-download (Tim Gallant)
  - Implement About to read size used (Nick Craig-Wood)
  - Add token renew function for jwt auth (David Bramwell)
  - Added support for interchangeable root folder for Box backend (Sunil Patra)
  - Remove unnecessary iat from jws claims (David)
  * Drive
  - Follow shortcuts by default, skip with --drive-skip-shortcuts (Nick Craig-Wood)
  - Implement rclone backend shortcut command for creating shortcuts (Nick Craig-Wood)
  - Added rclone backend command to change service_account_file and chunk_size (Anagh Kumar Baranwal)
  - Fix missing files when using --fast-list and --drive-shared-with-me (Nick Craig-Wood)
  - Fix duplicate items when using --drive-shared-with-me (Nick Craig-Wood)
  - Extend --drive-stop-on-upload-limit to respond to teamDriveFileLimitExceeded. (harry)
  - Don't delete files with multiple parents to avoid data loss (Nick Craig-Wood)
  - Server side copy docs use default description if empty (Nick Craig-Wood)
  * Dropbox
  - Make error insufficient space to be fatal (harry)
  - Add info about required redirect url (Elan Ruusamäe)
  * Fichier
  - Add support for --header-upload and --header-download (Tim Gallant)
  - Implement custom pacer to deal with the new rate limiting (buengese)
  * FTP
  - Fix lockup when using concurrency limit on failed connections (Nick Craig-Wood)
  - Fix lockup on failed upload when using concurrency limit (Nick Craig-Wood)
  - Fix lockup on Close failures when using concurrency limit (Nick Craig-Wood)
  - Work around pureftp sending spurious 150 messages (Nick Craig-Wood)
  * Google Cloud Storage
  - Add support for --header-upload and --header-download (Nick Craig-Wood)
  - Add ARCHIVE storage class to help (Adam Stroud)
  - Ignore directory markers at the root (Nick Craig-Wood)
  * Googlephotos
  - Make the start year configurable (Daven)
  - Add support for --header-upload and --header-download (Tim Gallant)
  - Create feature/favorites directory (Brandon Philips)
  - Fix "concurrent map write" error (Nick Craig-Wood)
  - Don't put an image in error message (Nick Craig-Wood)
  * HTTP
  - Improved directory listing with new template from Caddy project (calisro)
  * Jottacloud
  - Implement --jottacloud-trashed-only (buengese)
  - Add support for --header-upload and --header-download (Tim Gallant)
  - Use RawURLEncoding when decoding base64 encoded login token (buengese)
  - Implement cleanup (buengese)
  - Update docs regarding cleanup, removed remains from old auth, and added warning about special mountpoints. (albertony)
  * Mailru
  - Describe 2FA requirements (valery1707)
  * Onedrive
  - Implement --onedrive-server-side-across-configs (Nick Craig-Wood)
  - Add support for --header-upload and --header-download (Tim Gallant)
  - Fix occasional 416 errors on multipart uploads (Nick Craig-Wood)
  - Added maximum chunk size limit warning in the docs (Harry)
  - Fix missing drive on config (Nick Craig-Wood)
  - Make error quotaLimitReached to be fatal (harry)
  * Opendrive
  - Add support for --header-upload and --header-download (Tim Gallant)
  * Pcloud
  - Added support for interchangeable root folder for pCloud backend (Sunil Patra)
  - Add support for --header-upload and --header-download (Tim Gallant)
  - Fix initial config "Auth state doesn't match" message (Nick Craig-Wood)
  * Premiumizeme
  - Add support for --header-upload and --header-download (Tim Gallant)
  - Prune unused functions (Lars Lehtonen)
  * Putio
  - Add support for --header-upload and --header-download (Nick Craig-Wood)
  - Make downloading files use the rclone http Client (Nick Craig-Wood)
  - Fix parsing of remotes with leading and trailing / (Nick Craig-Wood)
  * Qingstor
  - Make rclone cleanup remove pending multipart uploads older than 24h (Nick Craig-Wood)
  - Try harder to cancel failed multipart uploads (Nick Craig-Wood)
  - Prune multiUploader.list() (Lars Lehtonen)
  - Lint fix (Lars Lehtonen)
  * S3
  - Add support for --header-upload and --header-download (Tim Gallant)
  - Use memory pool for buffer allocations (Maciej Zimnoch)
  - Add SSE-C support for AWS, Ceph, and MinIO (Jack Anderson)
  - Fail fast multipart upload (Michał Matczuk)
  - Report errors on bucket creation (mkdir) correctly (Nick Craig-Wood)
  - Specify that Minio supports URL encoding in listings (Nick Craig-Wood)
  - Added 500 as retryErrorCode (Michał Matczuk)
  - Use --low-level-retries as the number of SDK retries (Aleksandar Janković)
  - Fix multipart abort context (Aleksandar Jankovic)
  - Replace deprecated session.New() with session.NewSession() (Lars Lehtonen)
  - Use the provided size parameter when allocating a new memory pool (Joachim Brandon LeBlanc)
  - Use rclone's low level retries instead of AWS SDK to fix listing retries (Nick Craig-Wood)
  - Ignore directory markers at the root also (Nick Craig-Wood)
  - Use single memory pool (Michał Matczuk)
  - Do not resize buf on put to memBuf (Michał Matczuk)
  - Improve docs for --s3-disable-checksum (Nick Craig-Wood)
  - Don't leak memory or tokens in edge cases for multipart upload (Nick Craig-Wood)
  * Seafile
  - Implement 2FA (Fred)
  * SFTP
  - Added --sftp-pem-key to support inline key files (calisro)
  - Fix post transfer copies failing with 0 size when using set_modtime=false (Nick Craig-Wood)
  * Sharefile
  - Add support for --header-upload and --header-download (Tim Gallant)
  * Sugarsync
  - Add support for --header-upload and --header-download (Tim Gallant)
  * Swift
  - Add support for --header-upload and --header-download (Nick Craig-Wood)
  - Fix cosmetic issue in error message (Martin Michlmayr)
  * Union
  - Implement multiple writable remotes (Max Sum)
  - Fix server-side copy (Max Sum)
  - Implement ListR (Max Sum)
  - Enable ListR when upstreams contain local (Max Sum)
  * WebDAV
  - Add support for --header-upload and --header-download (Tim Gallant)
  - Fix X-OC-Mtime header for Transip compatibility (Nick Craig-Wood)
  - Report full and consistent usage with about (Yves G)
  * Yandex
  - Add support for --header-upload and --header-download (Tim Gallant)
* Sat Feb  1 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.51.0
  * See https://rclone.org/changelog/#v1-51-0-2020-02-01 for the
    complete changelog.
* Tue Nov 19 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.50.2
  * Bug Fixes
  - accounting: Fix memory leak on retries operations (Nick Craig-Wood)
  * Drive
  - Fix listing of the root directory with drive.files scope (Nick Craig-Wood)
  - Fix --drive-root-folder-id with team/shared drives (Nick Craig-Wood)
* Sat Nov  2 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.50.1
  * Bug Fixes
  - hash: Fix accidentally changed hash names for DropboxHash and CRC-32 (Nick Craig-Wood)
  - fshttp: Fix error reporting on tpslimit token bucket errors (Nick Craig-Wood)
  - fshttp: Don’t print token bucket errors on context cancelled (Nick Craig-Wood)
  * Local
  - Fix listings of . on Windows (Nick Craig-Wood)
  * Onedrive
  - Fix DirMove/Move after Onedrive change (Xiaoxing Ye)
* Sat Oct 26 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.50.0
  * New backends
  - Citrix Sharefile (Nick Craig-Wood)
  - Chunker - an overlay backend to split files into smaller parts (Ivan Andreev)
  - Mail.ru Cloud (Ivan Andreev)
  * New Features
  - encodings (Fabian Möller & Nick Craig-Wood)
  + All backends now use file name encoding to ensure any file name can be written to any backend.
  + See the restricted file name docs for more info and the local backend docs.
  + Some file names may look different in rclone if you are using any control characters in names or unicode FULLWIDTH symbols.
  - build
  + Update to use go1.13 for the build (Nick Craig-Wood)
  + Drop support for go1.9 (Nick Craig-Wood)
  + Build rclone with GitHub actions (Nick Craig-Wood)
  + Convert python scripts to python3 (Nick Craig-Wood)
  + Swap Azure/go-ansiterm for mattn/go-colorable (Nick Craig-Wood)
  + Dockerfile fixes (Matei David)
  + Add plugin support for backends and commands (Richard Patel)
  - config
  + Use alternating Red/Green in config to make more obvious (Nick Craig-Wood)
  - contrib
  + Add sample DLNA server Docker Compose manifest. (pataquets)
  + Add sample WebDAV server Docker Compose manifest. (pataquets)
  - copyurl
  + Add --auto-filename flag for using file name from URL in destination path (Denis)
  - serve dlna:
  + Many compatability improvements (Dan Walters)
  + Support for external srt subtitles (Dan Walters)
  - rc
  + Added command core/quit (Saksham Khanna)
  * Bug Fixes
  - sync
  + Make --update/-u not transfer files that haven’t changed (Nick Craig-Wood)
  + Free objects after they come out of the transfer pipe to save memory (Nick Craig-Wood)
  + Fix --files-from without --no-traverse doing a recursive scan (Nick Craig-Wood)
  - operations
  + Fix accounting for server side copies (Nick Craig-Wood)
  + Display ‘All duplicates removed’ only if dedupe successful (Sezal Agrawal)
  + Display ‘Deleted X extra copies’ only if dedupe successful (Sezal Agrawal)
  - accounting
  + Only allow up to 100 completed transfers in the accounting list to save memory (Nick Craig-Wood)
  + Cull the old time ranges when possible to save memory (Nick Craig-Wood)
  + Fix panic due to server-side copy fallback (Ivan Andreev)
  + Fix memory leak noticeable for transfers of large numbers of objects (Nick Craig-Wood)
  + Fix total duration calculation (Nick Craig-Wood)
  - cmd
  + Fix environment variables not setting command line flags (Nick Craig-Wood)
  + Make autocomplete compatible with bash’s posix mode for macOS (Danil Semelenov)
  + Make --progress work in git bash on Windows (Nick Craig-Wood)
  + Fix ‘compopt: command not found’ on autocomplete on macOS (Danil Semelenov)
  - config
  + Fix setting of non top level flags from environment variables (Nick Craig-Wood)
  + Check config names more carefully and report errors (Nick Craig-Wood)
  + Remove error: can’t use --size-only and --ignore-size together. (Nick Craig-Wood)
  + filter: Prevent mixing options when --files-from is in use (Michele Caci)
  + serve sftp: Fix crash on unsupported operations (eg Readlink) (Nick Craig-Wood)
  * Mount
  - Allow files of unkown size to be read properly (Nick Craig-Wood)
  - Skip tests on <= 2 CPUs to avoid lockup (Nick Craig-Wood)
  - Fix panic on File.Open (Nick Craig-Wood)
  - Fix “mount_fusefs: -o timeout=: option not supported” on FreeBSD (Nick Craig-Wood)
  - Don’t pass huge filenames (>4k) to FUSE as it can’t cope (Nick Craig-Wood)
  * VFS
  - Add flag --vfs-case-insensitive for windows/macOS mounts (Ivan Andreev)
  - Make objects of unknown size readable through the VFS (Nick Craig-Wood)
  - Move writeback of dirty data out of close() method into its own method (FlushWrites) and remove close() call from Flush() (Brett Dutro)
  - Stop empty dirs disappearing when renamed on bucket based remotes (Nick Craig-Wood)
  - Stop change notify polling clearing so much of the directory cache (Nick Craig-Wood)
  * Azure Blob
  - Disable logging to the Windows event log (Nick Craig-Wood)
  * B2
  - Remove unverified: prefix on sha1 to improve interop (eg with CyberDuck) (Nick Craig-Wood)
  * Box
  - Add options to get access token via JWT auth (David)
  * Drive
  - Disable HTTP/2 by default to work around INTERNAL_ERROR problems (Nick Craig-Wood)
  - Make sure that drive root ID is always canonical (Nick Craig-Wood)
  - Fix --drive-shared-with-me from the root with lsand --fast-list (Nick Craig-Wood)
  - Fix ChangeNotify polling for shared drives (Nick Craig-Wood)
  - Fix change notify polling when using appDataFolder (Nick Craig-Wood)
  * Dropbox
  - Make disallowed filenames errors not retry (Nick Craig-Wood)
  - Fix nil pointer exception on restricted files (Nick Craig-Wood)
  * Fichier
  - Fix accessing files > 2GB on 32 bit systems (Nick Craig-Wood)
  * FTP
  - Allow disabling EPSV mode (Jon Fautley)
  * HTTP
  - HEAD directory entries in parallel to speedup (Nick Craig-Wood)
  - Add --http-no-head to stop rclone doing HEAD in listings (Nick Craig-Wood)
  * Putio
  - Add ability to resume uploads (Cenk Alti)
  * S3
  - Fix signature v2_auth headers (Anthony Rusdi)
  - Fix encoding for control characters (Nick Craig-Wood)
  - Only ask for URL encoded directory listings if we need them on Ceph (Nick Craig-Wood)
  - Add option for multipart failiure behaviour (Aleksandar Jankovic)
  - Support for multipart copy (庄天翼)
  - Fix nil pointer reference if no metadata returned for object (Nick Craig-Wood)
  * SFTP
  - Fix --sftp-ask-password trying to contact the ssh agent (Nick Craig-Wood)
  - Fix hashes of files with backslashes (Nick Craig-Wood)
  - Include more ciphers with --sftp-use-insecure-cipher (Carlos Ferreyra)
  * WebDAV
  - Parse and return Sharepoint error response (Henning Surmeier)
* Sun Sep 29 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.49.4
  * Bug Fixes
  - cmd/rcd: Address ZipSlip vulnerability (Richard Patel)
  - accounting: Fix file handle leak on errors (Nick Craig-Wood)
  - oauthutil: Fix security problem when running with two users on the same machine (Nick Craig-Wood)
  * FTP
  - Fix listing of an empty root returning: error dir not found (Nick Craig-Wood)
  * S3
  - Fix SetModTime on GLACIER/ARCHIVE objects and implement set/get tier (Nick Craig-Wood)
* Sun Sep 15 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.49.3
  * Bug Fixes
  - accounting
    + Fix total duration calculation (Aleksandar Jankovic)
    + Fix “file already closed” on transfer retries (Nick Craig-Wood)
* Sun Sep  8 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.49.2
  * New Features
  - build: Add Docker workflow support (Alfonso Montero)
  * Bug Fixes
  - accounting: Fix locking in Transfer to avoid deadlock with --progress (Nick Craig-Wood)
  - docs: Fix template argument for mktemp in install.sh (Cnly)
  - operations: Fix -u/--update with google photos / files of unknown size (Nick Craig-Wood)
  - rc: Fix docs for config/create /update /password (Nick Craig-Wood)
  * Google Cloud Storage
  - Fix need for elevated permissions on SetModTime (Nick Craig-Wood)
* Thu Aug 29 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.49.1
  * Bug Fixes
  - config: Fix generated passwords being stored as empty password (Nick Craig-Wood)
  - rcd: Added missing parameter for web-gui info logs. (Chaitanya)
  * Googlephotos
  - Fix crash on error response (Nick Craig-Wood)
  * Onedrive
  - Fix crash on error response (Nick Craig-Wood)
* Mon Aug 26 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.49.0
  * New backends
  - 1fichier (Laura Hausmann)
  - Google Photos (Nick Craig-Wood)
  - Putio (Cenk Alti)
  - premiumize.me (Nick Craig-Wood)
  * New Features
  - Experimental web GUI (Chaitanya Bankanhal)
  - Implement --compare-dest & --copy-dest (yparitcher)
  - Implement --suffix without --backup-dir for backup to current dir (yparitcher)
  - config reconnect to re-login (re-run the oauth login) for the backend. (Nick Craig-Wood)
  - config userinfo to discover which user you are logged in as. (Nick Craig-Wood)
  - config disconnect to disconnect you (log out) from the backend. (Nick Craig-Wood)
  - Add --use-json-log for JSON logging (justinalin)
  - Add context propagation to rclone (Aleksandar Jankovic)
  - Reworking internal statistics interfaces so they work with rc jobs (Aleksandar Jankovic)
  - Add Higher units for ETA (AbelThar)
  - Update rclone logos to new design (Andreas Chlupka)
  - hash: Add CRC-32 support (Cenk Alti)
  - help showbackend: Fixed advanced option category when there are no standard options (buengese)
  - ncdu: Display/Copy to Clipboard Current Path (Gary Kim)
  - operations:
    + Run hashing operations in parallel (Nick Craig-Wood)
    + Don’t calculate checksums when using --ignore-checksum (Nick Craig-Wood)
    + Check transfer hashes when using --size-only mode (Nick Craig-Wood)
    + Disable multi thread copy for local to local copies (Nick Craig-Wood)
    + Debug successful hashes as well as failures (Nick Craig-Wood)
  - rc
    + Add ability to stop async jobs (Aleksandar Jankovic)
    + Return current settings if core/bwlimit called without parameters (Nick Craig-Wood)
    + Rclone-WebUI integration with rclone (Chaitanya Bankanhal)
    + Added command line parameter to control the cross origin resource sharing (CORS) in the rcd. (Security Improvement) (Chaitanya Bankanhal)
    + Add anchor tags to the docs so links are consistent (Nick Craig-Wood)
    + Remove _async key from input parameters after parsing so later operations won’t get confused (buengese)
    + Add call to clear stats (Aleksandar Jankovic)
  - rcd
    + Auto-login for web-gui (Chaitanya Bankanhal)
    + Implement --baseurl for rcd and web-gui (Chaitanya Bankanhal)
  - serve dlna
    + Only select interfaces which can multicast for SSDP (Nick Craig-Wood)
    + Add more builtin mime types to cover standard audio/video (Nick Craig-Wood)
    + Fix missing mime types on Android causing missing videos (Nick Craig-Wood)
  - serve ftp
    + Refactor to bring into line with other serve commands (Nick Craig-Wood)
    + Implement --auth-proxy (Nick Craig-Wood)
  - serve http: Implement --baseurl (Nick Craig-Wood)
  - serve restic: Implement --baseurl (Nick Craig-Wood)
  - serve sftp
    + Implement auth proxy (Nick Craig-Wood)
    + Fix detection of whether server is authorized (Nick Craig-Wood)
  - serve webdav
    + Implement --baseurl (Nick Craig-Wood)
    + Support --auth-proxy (Nick Craig-Wood)
  * Bug Fixes
  - Make “bad record MAC” a retriable error (Nick Craig-Wood)
  - copyurl: Fix copying files that return HTTP errors (Nick Craig-Wood)
  - march: Fix checking sub-directories when using --no-traverse (buengese)
  - rc
    + Fix unmarshalable http.AuthFn in options and put in test for marshalability (Nick Craig-Wood)
    + Move job expire flags to rc to fix initalization problem (Nick Craig-Wood)
    + Fix --loopback with rc/list and others (Nick Craig-Wood)
  - rcat: Fix slowdown on systems with multiple hashes (Nick Craig-Wood)
  - rcd: Fix permissions problems on cache directory with web gui download (Nick Craig-Wood)
  * Mount
  - Default --deamon-timout to 15 minutes on macOS and FreeBSD (Nick Craig-Wood)
  - Update docs to show mounting from root OK for bucket based (Nick Craig-Wood)
  - Remove nonseekable flag from write files (Nick Craig-Wood)
  * VFS
  - Make write without cache more efficient (Nick Craig-Wood)
  - Fix --vfs-cache-mode minimal and writes ignoring cached files (Nick Craig-Wood)
  * Local
  - Add --local-case-sensitive and --local-case-insensitive (Nick Craig-Wood)
  - Avoid polluting page cache when uploading local files to remote backends (Michał Matczuk)
  - Don’t calculate any hashes by default (Nick Craig-Wood)
  - Fadvise run syscall on a dedicated go routine (Michał Matczuk)
  * Azure Blob
  - Azure Storage Emulator support (Sandeep)
  - Updated config help details to remove connection string references (Sandeep)
  - Make all operations work from the root (Nick Craig-Wood)
  * B2
  - Implement link sharing (yparitcher)
  - Enable server side copy to copy between buckets (Nick Craig-Wood)
  - Make all operations work from the root (Nick Craig-Wood)
  * Drive
  - Fix server side copy of big files (Nick Craig-Wood)
  - Update API for teamdrive use (Nick Craig-Wood)
  - Add error for purge with --drive-trashed-only (ginvine)
  * Fichier
  - Make FolderID int and adjust related code (buengese)
  * Google Cloud Storage
  - Reduce oauth scope requested as suggested by Google (Nick Craig-Wood)
  - Make all operations work from the root (Nick Craig-Wood)
  * HTTP
  - Add --http-headers flag for setting arbitrary headers (Nick Craig-Wood)
  * Jottacloud
  - Use new api for retrieving internal username (buengese)
  - Refactor configuration and minor cleanup (buengese)
  * Koofr
  - Support setting modification times on Koofr backend. (jaKa)
  * Opendrive
  - Refactor to use existing lib/rest facilities for uploads (Nick Craig-Wood)
  * Qingstor
  - Upgrade to v3 SDK and fix listing loop (Nick Craig-Wood)
  - Make all operations work from the root (Nick Craig-Wood)
  * S3
  - Add INTELLIGENT_TIERING storage class (Matti Niemenmaa)
  - Make all operations work from the root (Nick Craig-Wood)
  * SFTP
  - Add missing interface check and fix About (Nick Craig-Wood)
  - Completely ignore all modtime checks if SetModTime=false (Jon Fautley)
  - Support md5/sha1 with rsync.net (Nick Craig-Wood)
  - Save the md5/sha1 command in use to the config file for efficiency (Nick Craig-Wood)
  - Opt-in support for diffie-hellman-group-exchange-sha256 diffie-hellman-group-exchange-sha1 (Yi FU)
  * Swift
  - Use FixRangeOption to fix 0 length files via the VFS (Nick Craig-Wood)
  - Fix upload when using no_chunk to return the correct size (Nick Craig-Wood)
  - Make all operations work from the root (Nick Craig-Wood)
  - Fix segments leak during failed large file uploads. (nguyenhuuluan434)
  * WebDAV
  - Add --webdav-bearer-token-command (Nick Craig-Wood)
  - Refresh token when it expires with --webdav-bearer-token-command (Nick Craig-Wood)
  - Add docs for using bearer_token_command with oidc-agent (Paul Millar)
* Thu Jun 20 2019 Ismail Dönmez <idonmez@suse.com>
- Fix executable permission boo#1140423
- Update to version 1.48.0
  * New commands
  - serve sftp: Serve an rclone remote over SFTP (Nick Craig-Wood)
  * New Features
  - Multi threaded downloads to local storage (Nick Craig-Wood)
    controlled with --multi-thread-cutoff and --multi-thread-streams
  - Use rclone.conf from rclone executable directory to enable portable use (albertony)
  - Allow sync of a file and a directory with the same name (forgems)
    this is common on bucket based remotes, eg s3, gcs
  - Add --ignore-case-sync for forced case insensitivity (garry415)
  - Implement --stats-one-line-date and --stats-one-line-date-format (Peter Berbec)
  - Log an ERROR for all commands which exit with non-zero status (Nick Craig-Wood)
  - Use go-homedir to read the home directory more reliably (Nick Craig-Wood)
  - Enable creating encrypted config through external script invocation (Wojciech Smigielski)
  - build: Drop support for go1.8 (Nick Craig-Wood)
  - config: Make config create/update encrypt passwords where necessary (Nick Craig-Wood)
  - copyurl: Honor --no-check-certificate (Stefan Breunig)
  - install: Linux skip man pages if no mandb (didil)
  - lsf: Support showing the Tier of the object (Nick Craig-Wood)
  - lsjson
    + Added EncryptedPath to output (calisro)
    + Support showing the Tier of the object (Nick Craig-Wood)
    + Add IsBucket field for bucket based remote listing of the root (Nick Craig-Wood)
  - rc
    + Add --loopback flag to run commands directly without a server (Nick Craig-Wood)
    + Add operations/fsinfo: Return information about the remote (Nick Craig-Wood)
    + Skip auth for OPTIONS request (Nick Craig-Wood)
    + cmd/providers: Add DefaultStr, ValueStr and Type fields (Nick Craig-Wood)
    + jobs: Make job expiry timeouts configurable (Aleksandar Jankovic)
  - serve dlna reworked and improved (Dan Walters)
  - serve ftp: add --ftp-public-ip flag to specify public IP (calistri)
  - serve restic: Add support for --private-repos in serve restic (Florian Apolloner)
  - serve webdav: Combine serve webdav and serve http (Gary Kim)
  - size: Ignore negative sizes when calculating total (Garry McNulty)
  * Bug Fixes
  - Make move and copy individual files obey --backup-dir (Nick Craig-Wood)
  - If --ignore-checksum is in effect, don’t calculate checksum (Nick Craig-Wood)
  - moveto: Fix case-insensitive same remote move (Gary Kim)
  - rc: Fix serving bucket based objects with --rc-serve (Nick Craig-Wood)
  - serve webdav: Fix serveDir not being updated with changes from webdav (Gary Kim)
  * Mount
  - Fix poll interval documentation (Animosity022)
  * VFS
  - Make WriteAt for non cached files work with non-sequential writes (Nick Craig-Wood)
  * Local
  - Only calculate the required hashes for big speedup (Nick Craig-Wood)
  - Log errors when listing instead of returning an error (Nick Craig-Wood)
  - Fix preallocate warning on Linux with ZFS (Nick Craig-Wood)
  * Crypt
  - Make rclone dedupe work through crypt (Nick Craig-Wood)
  - Fix wrapping of ChangeNotify to decrypt directories properly (Nick Craig-Wood)
  - Support PublicLink (rclone link) of underlying backend (Nick Craig-Wood)
  - Implement Optional methods SetTier, GetTier (Nick Craig-Wood)
  * B2
  - Implement server side copy (Nick Craig-Wood)
  - Implement SetModTime (Nick Craig-Wood)
  * Drive
  - Fix move and copy from TeamDrive to GDrive (Fionera)
  - Add notes that cleanup works in the background on drive (Nick Craig-Wood)
  - Add --drive-server-side-across-configs to default back to old server side copy semantics by default (Nick Craig-Wood)
  - Add --drive-size-as-quota to show storage quota usage for file size (Garry McNulty)
  * FTP
  - Add FTP List timeout (Jeff Quinn)
  - Add FTP over TLS support (Gary Kim)
  - Add --ftp-no-check-certificate option for FTPS (Gary Kim)
  * Google Cloud Storage
  - Fix upload errors when uploading pre 1970 files (Nick Craig-Wood)
  * Jottacloud
  - Add support for selecting device and mountpoint. (buengese)
  * Mega
  - Add cleanup support (Gary Kim)
  * Onedrive
  - More accurately check if root is found (Cnly)
  * S3
  - Suppport S3 Accelerated endpoints with --s3-use-accelerate-endpoint (Nick Craig-Wood)
  - Add config info for Wasabi’s EU Central endpoint (Robert Marko)
  - Make SetModTime work for GLACIER while syncing (Philip Harvey)
  * SFTP
  - Add About support (Gary Kim)
  - Fix about parsing of df results so it can cope with -ve results (Nick Craig-Wood)
  - Send custom client version and debug server version (Nick Craig-Wood)
  * WebDAV
  - Retry on 423 Locked errors (Nick Craig-Wood)
* Sun Jun  9 2019 Aleksa Sarai <asarai@suse.com>
- Update to version 1.47.0. boo#1137685
  - New backends
  - Backend for Koofr cloud storage service. (jaKa)
  - New Features
  - Resume downloads if the reader fails in copy (Nick Craig-Wood)
  - Use `--fast-list` for listing operations where it won't use more memory (Nick Craig-Wood)
  - Make `--files-from` traverse the destination unless `--no-traverse` is set (Nick Craig-Wood)
  - Make server side copy account bytes and obey `--max-transfer` (Nick Craig-Wood)
  - Add `--create-empty-src-dirs` flag and default to not creating empty dirs (ishuah)
  - Add client side TLS/SSL flags `--ca-cert`/`--client-cert`/`--client-key` (Nick Craig-Wood)
  - Implement `--suffix-keep-extension` for use with `--suffix` (Nick Craig-Wood)
  - serve dlna: Add connection manager service description to improve compatibility (Dan Walters)
  - lsf: Add 'e' format to show encrypted names and 'o' for original IDs (Nick Craig-Wood)
  - lsjson: Added `--files-only` and `--dirs-only` flags (calistri)
  - rc: Implement operations/publiclink the equivalent of `rclone link` (Nick Craig-Wood)
  - Bug Fixes
  - accounting: Fix total ETA when `--stats-unit bits` is in effect (Nick Craig-Wood)
  - Bash TAB completion
  - Use private custom func to fix clash between rclone and kubectl (Nick Craig-Wood)
  - Fix for remotes with underscores in their names (Six)
  - Fix completion of remotes (Florian Gamböck)
  - Fix autocompletion of remote paths with spaces (Danil Semelenov)
  - serve dlna: Fix root XML service descriptor (Dan Walters)
  - ncdu: Fix display corruption with Chinese characters (Nick Craig-Wood)
  - Add SIGTERM to signals which run the exit handlers on unix (Nick Craig-Wood)
  - rc: Reload filter when the options are set via the rc (Nick Craig-Wood)
  - VFS / Mount
  - Fix FreeBSD: Ignore Truncate if called with no readers and already the correct size (Nick Craig-Wood)
  - Read directory and check for a file before mkdir (Nick Craig-Wood)
  - Shorten the locking window for vfs/refresh (Nick Craig-Wood)
  - Azure Blob
  - Enable MD5 checksums when uploading files bigger than the "Cutoff" (Dr.Rx)
  - Fix SAS URL support (Nick Craig-Wood)
  - B2
  - Allow manual configuration of backblaze downloadUrl (Vince)
  - Ignore already_hidden error on remove (Nick Craig-Wood)
  - Ignore malformed `src_last_modified_millis` (Nick Craig-Wood)
  - Drive
  - Add `--skip-checksum-gphotos` to ignore incorrect checksums on Google Photos (Nick Craig-Wood)
  - Allow server side move/copy between different remotes. (Fionera)
  - Add docs on team drives and `--fast-list` eventual consistency (Nestar47)
  - Fix imports of text files (Nick Craig-Wood)
  - Fix range requests on 0 length files (Nick Craig-Wood)
  - Fix creation of duplicates with server side copy (Nick Craig-Wood)
  - Dropbox
  - Retry blank errors to fix long listings (Nick Craig-Wood)
  - FTP
  - Add `--ftp-concurrency` to limit maximum number of connections (Nick Craig-Wood)
  - Google Cloud Storage
  - Fall back to default application credentials (marcintustin)
  - Allow bucket policy only buckets (Nick Craig-Wood)
  - HTTP
  - Add `--http-no-slash` for websites with directories with no slashes (Nick Craig-Wood)
  - Remove duplicates from listings (Nick Craig-Wood)
  - Fix socket leak on 404 errors (Nick Craig-Wood)
  - Jottacloud
  - Fix token refresh (Sebastian Bünger)
  - Add device registration (Oliver Heyme)
  - Onedrive
  - Implement graceful cancel of multipart uploads if rclone is interrupted (Cnly)
  - Always add trailing colon to path when addressing items, (Cnly)
  - Return errors instead of panic for invalid uploads (Fabian Möller)
  - S3
  - Add support for "Glacier Deep Archive" storage class (Manu)
  - Update Dreamhost endpoint (Nick Craig-Wood)
  - Note incompatibility with CEPH Jewel (Nick Craig-Wood)
  - SFTP
  - Allow custom ssh client config (Alexandru Bumbacea)
  - Swift
  - Obey Retry-After to enable OVH restore from cold storage (Nick Craig-Wood)
  - Work around token expiry on CEPH (Nick Craig-Wood)
  - WebDAV
  - Allow IsCollection property to be integer or boolean (Nick Craig-Wood)
  - Fix race when creating directories (Nick Craig-Wood)
  - Fix About/df when reading the available/total returns 0 (Nick Craig-Wood)
- Add bash-completion and zsh-completion support.
* Thu Mar 14 2019 Marcus Rueckert <mrueckert@suse.de>
- bump required go to 1.11 as we are using the mod support
* Thu Mar 14 2019 Marcus Rueckert <mrueckert@suse.de>
- Update to version 1.46:
  - New backends
  - Support Alibaba Cloud (Aliyun) OSS via the s3 backend (Nick Craig-Wood)
  - New commands
  - serve dlna: serves a remove via DLNA for the local network (nicolov)
  - New Features
  - copy, move: Restore deprecated --no-traverse flag (Nick Craig-Wood)
  - This is useful for when transferring a small number of files into a large destination
  - genautocomplete: Add remote path completion for bash completion (Christopher Peterson & Danil Semelenov)
  - Buffer memory handling reworked to return memory to the OS better (Nick Craig-Wood)
  - Buffer recycling library to replace sync.Pool
  - Optionally use memory mapped memory for better memory shrinking
  - Enable with --use-mmap if having memory problems - not default yet
  - Parallelise reading of files specified by --files-from (Nick Craig-Wood)
  - check: Add stats showing total files matched. (Dario Guzik)
  - Allow rename/delete open files under Windows (Nick Craig-Wood)
  - lsjson: Use exactly the correct number of decimal places in the seconds (Nick Craig-Wood)
  - Add cookie support with cmdline switch --use-cookies for all HTTP based remotes (qip)
  - Warn if --checksum is set but there are no hashes available (Nick Craig-Wood)
  - Rework rate limiting (pacer) to be more accurate and allow bursting (Nick Craig-Wood)
  - Improve error reporting for too many/few arguments in commands (Nick Craig-Wood)
  - listremotes: Remove -l short flag as it conflicts with the new global flag (weetmuts)
  - Make http serving with auth generate INFO messages on auth fail (Nick Craig-Wood)
  - Bug Fixes
  - Fix layout of stats (Nick Craig-Wood)
  - Fix --progress crash under Windows Jenkins (Nick Craig-Wood)
  - Fix transfer of google/onedrive docs by calling Rcat in Copy when size is -1 (Cnly)
  - copyurl: Fix checking of --dry-run (Denis Skovpen)
  - Mount
  - Check that mountpoint and local directory to mount don’t overlap (Nick Craig-Wood)
  - Fix mount size under 32 bit Windows (Nick Craig-Wood)
  - VFS
  - Implement renaming of directories for backends without DirMove (Nick Craig-Wood)
  - now all backends except b2 support renaming directories
  - Implement --vfs-cache-max-size to limit the total size of the cache (Nick Craig-Wood)
  - Add --dir-perms and --file-perms flags to set default permissions (Nick Craig-Wood)
  - Fix deadlock on concurrent operations on a directory (Nick Craig-Wood)
  - Fix deadlock between RWFileHandle.close and File.Remove (Nick Craig-Wood)
  - Fix renaming/deleting open files with cache mode “writes” under Windows (Nick Craig-Wood)
  - Fix panic on rename with --dry-run set (Nick Craig-Wood)
  - Fix vfs/refresh with recurse=true needing the --fast-list flag
  - Local
  - Add support for -l/--links (symbolic link translation) (yair@unicorn)
  - this works by showing links as link.rclonelink - see local backend docs for more info
  - this errors if used with -L/--copy-links
  - Fix renaming/deleting open files on Windows (Nick Craig-Wood)
  - Crypt
  - Check for maximum length before decrypting filename to fix panic (Garry McNulty)
  - Azure Blob
  - Allow building azureblob backend on *BSD (themylogin)
  - Use the rclone HTTP client to support --dump headers, --tpslimit etc (Nick Craig-Wood)
  - Use the s3 pacer for 0 delay in non error conditions (Nick Craig-Wood)
  - Ignore directory markers (Nick Craig-Wood)
  - Stop Mkdir attempting to create existing containers (Nick Craig-Wood)
  - B2
  - cleanup: will remove unfinished large files >24hrs old (Garry McNulty)
  - For a bucket limited application key check the bucket name (Nick Craig-Wood)
  - before this, rclone would use the authorised bucket regardless of what you put on the command line
  - Added --b2-disable-checksum flag (Wojciech Smigielski)
  - this enables large files to be uploaded without a SHA-1 hash for speed reasons
  - Drive
  - Set default pacer to 100ms for 10 tps (Nick Craig-Wood)
  - This fits the Google defaults much better and reduces the 403 errors massively
  - Add --drive-pacer-min-sleep and --drive-pacer-burst to control the pacer
  - Improve ChangeNotify support for items with multiple parents (Fabian Möller)
  - Fix ListR for items with multiple parents - this fixes oddities with vfs/refresh (Fabian Möller)
  - Fix using --drive-impersonate and appfolders (Nick Craig-Wood)
  - Fix google docs in rclone mount for some (not all) applications (Nick Craig-Wood)
  - Dropbox
  - Retry-After support for Dropbox backend (Mathieu Carbou)
  - FTP
  - Wait for 60 seconds for a connection to Close then declare it dead (Nick Craig-Wood)
  - helps with indefinite hangs on some FTP servers
  - Google Cloud Storage
  - Update google cloud storage endpoints (weetmuts)
  - HTTP
  - Add an example with username and password which is supported but wasn’t documented (Nick Craig-Wood)
  - Fix backend with --files-from and non-existent files (Nick Craig-Wood)
  - Hubic
  - Make error message more informative if authentication fails (Nick Craig-Wood)
  - Jottacloud
  - Resume and deduplication support (Oliver Heyme)
  - Use token auth for all API requests Don’t store password anymore (Sebastian Bünger)
  - Add support for 2-factor authentification (Sebastian Bünger)
  - Mega
  - Implement v2 account login which fixes logins for newer Mega accounts (Nick Craig-Wood)
  - Return error if an unknown length file is attempted to be uploaded (Nick Craig-Wood)
  - Add new error codes for better error reporting (Nick Craig-Wood)
  - Onedrive
  - Fix broken support for “shared with me” folders (Alex Chen)
  - Fix root ID not normalised (Cnly)
  - Return err instead of panic on unknown-sized uploads (Cnly)
  - Qingstor
  - Fix go routine leak on multipart upload errors (Nick Craig-Wood)
  - Add upload chunk size/concurrency/cutoff control (Nick Craig-Wood)
  - Default --qingstor-upload-concurrency to 1 to work around bug (Nick Craig-Wood)
  - S3
  - Implement --s3-upload-cutoff for single part uploads below this (Nick Craig-Wood)
  - Change --s3-upload-concurrency default to 4 to increase perfomance (Nick Craig-Wood)
  - Add --s3-bucket-acl to control bucket ACL (Nick Craig-Wood)
  - Auto detect region for buckets on operation failure (Nick Craig-Wood)
  - Add GLACIER storage class (William Cocker)
  - Add Scaleway to s3 documentation (Rémy Léone)
  - Add AWS endpoint eu-north-1 (weetmuts)
  - SFTP
  - Add support for PEM encrypted private keys (Fabian Möller)
  - Add option to force the usage of an ssh-agent (Fabian Möller)
  - Perform environment variable expansion on key-file (Fabian Möller)
  - Fix rmdir on Windows based servers (eg CrushFTP) (Nick Craig-Wood)
  - Fix rmdir deleting directory contents on some SFTP servers (Nick Craig-Wood)
  - Fix error on dangling symlinks (Nick Craig-Wood)
  - Swift
  - Add --swift-no-chunk to disable segmented uploads in rcat/mount (Nick Craig-Wood)
  - Introduce application credential auth support (kayrus)
  - Fix memory usage by slimming Object (Nick Craig-Wood)
  - Fix extra requests on upload (Nick Craig-Wood)
  - Fix reauth on big files (Nick Craig-Wood)
  - Union
  - Fix poll-interval not working (Nick Craig-Wood)
  - WebDAV
  - Support About which means rclone mount will show the correct disk size (Nick Craig-Wood)
  - Support MD5 and SHA1 hashes with Owncloud and Nextcloud (Nick Craig-Wood)
  - Fail soft on time parsing errors (Nick Craig-Wood)
  - Fix infinite loop on failed directory creation (Nick Craig-Wood)
  - Fix identification of directories for Bitrix Site Manager (Nick Craig-Wood)
  - Fix upload of 0 length files on some servers (Nick Craig-Wood)
  - Fix if MKCOL fails with 423 Locked assume the directory exists (Nick Craig-Wood)
* Mon Dec  3 2018 Ismail Dönmez <idonmez@suse.com>
- Update to version v1.45
  * See https://rclone.org/changelog/ for the complete changelog.
* Thu Sep 27 2018 Ismail Dönmez <idonmez@suse.com>
- Update to version v1.43.1
  * See https://rclone.org/changelog/ for the complete changelog.
- Switch to obs_scm
* Sat Jun 23 2018 asarai@suse.com
- Update to rclone v1.42.
  See https://rclone.org/changelog/ for changelog.
- Switch to %%license macro.
* Tue Jun  5 2018 jacobwinski@gmail.com
- Update to rclone v1.41.
  * Too many changes to list, please see
    https://rclone.org/changelog/ for the complete changelog.
* Tue Jun  5 2018 jacobwinski@gmail.com
- Fix spec file causing build error (unresolvable) on Leap 42.3.
* Fri Apr 13 2018 asarai@suse.com
- Update to rclone v1.40.
* Sat Jan 13 2018 asarai@suse.com
- Initial import of rclone v1.39, an rsync-like utility for cloud storage.
